/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.blog.ribbon.control.button');

org.ametys.ribbon.control.button.ValidateActionButton = function(id, configuration, pluginName) 
{
	org.ametys.ribbon.control.button.ValidateActionButton.superclass.constructor.call(this, id, configuration, pluginName);
};

Ext.extend(org.ametys.ribbon.control.button.ValidateActionButton, org.ametys.ribbon.control.button.ActionButton, {});

org.ametys.ribbon.control.button.ValidateActionButton.prototype._params;

org.ametys.ribbon.control.button.ValidateActionButton.prototype._testTarget = function(target)
{
	if (org.ametys.ribbon.control.button.ValidateActionButton.superclass.constructor._testTarget(this, target))
	{
		return target.getParameters()["validated"] == this.getConfiguration()["validated"];
	}
	else
	{
		return false;
	}
}
org.ametys.ribbon.control.button.ValidateActionButton.prototype.onMessage = function(messages)
{
	var atLeastOneInvalidated = false;
	
	for (var i=0; (i < messages.length) && (!atLeastOneInvalidated); i++)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
		{
			var alltargets = messages[i].getTargets();
			
			var targets = org.ametys.messagebus.message.MessageTargetHelper.findAll(alltargets, function(target) {return target.getType() == "content"} );

			if (targets.length > 0)
			{
				var params = {};
				for (var i = 0; i < targets.length; i++)
				{
					var contentTarget = targets[i];
					var contentId = contentTarget.getParameters()['id'];
					
					var subtargets = org.ametys.messagebus.message.MessageTargetHelper.findAll(contentTarget.getSubTargets(), function(target) {return target.getType() == 'comment'});
					for (var j = 0; j < subtargets.length; j++)
					{
						var commentTarget = subtargets[j];
						var commentId = commentTarget.getParameters()['id'];
						
						if (params[contentId] == null)
						{
							params[contentId] = []; 
						}
						var comments = params[contentId];
						comments.push(commentId);
					}
				}
	
				if (!this._areTheSame(this._params, params))
				{
					this._params = params;
					org.ametys.ribbon.RibbonManager.getInstance().refreshElement('control', this, params);
				}
			}
			else
			{
				this.getElements().each(function(element) { element.stopRefreshing(); element.setDisabled(true); });
				this.updateTooltip(this.getConfiguration()["default-description"]);
			}
		}
		else if (messages[i].getType().getName() == "commentsRemoved" || messages[i].getType().getName() == "commentsInvalidated" || messages[i].getType().getName() == "commentsValidated")
		{
			var alltargets = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
			
			var targets = org.ametys.messagebus.message.MessageTargetHelper.findAll(alltargets, function(target) {return target.getType() == "content"} );

			if (targets.length > 0)
			{
				var params = {};
				for (var i = 0; i < targets.length; i++)
				{
					var contentTarget = targets[i];
					var contentId = contentTarget.getParameters()['id'];
					
					var subtargets = org.ametys.messagebus.message.MessageTargetHelper.findAll(contentTarget.getSubTargets(), function(target) {return target.getType() == 'comment'});
					for (var j = 0; j < subtargets.length; j++)
					{
						var commentTarget = subtargets[j];
						var commentId = commentTarget.getParameters()['id'];
						
						if (params[contentId] == null)
						{
							params[contentId] = []; 
						}
						var comments = params[contentId];
						comments.push(commentId);
					}
				}
	
				org.ametys.ribbon.RibbonManager.getInstance().refreshElement('control', this, params);
			}
		}
	}
}

org.ametys.ribbon.control.button.ValidateActionButton.prototype.configurationError = function(response)
{
	this.getElements().each(function(element) { element.stopRefreshing(); element.setDisabled(true); });
	this.updateTooltip(this.getConfiguration()["default-description"]);
}

org.ametys.ribbon.control.button.ValidateActionButton.prototype.configurationChanged = function(params)
{
	this.getElements().each(function(element) { element.stopRefreshing(); });

	var atLeastOne = false;
	for (var i in params)
	{
		if (params[i] == "false" && this.getConfiguration()["validated"] == "true"
			|| params[i] == "true" && this.getConfiguration()["validated"] == "false")
		{
			atLeastOne = true
		}
	}

	this.getElements().each(function(element) { element.setDisabled(!atLeastOne); });
}

org.ametys.ribbon.control.button.ValidateActionButton.prototype._convertToId = function (targets)
{
	var targetsIds = [];
	for (var i = 0; i < targets.length; i++)
	{
		targetsIds.push(targets[i].getParameters()['id']);
	}
	return targetsIds;
}

org.ametys.ribbon.control.button.ValidateActionButton.prototype._areTheSame = function (o1, o2)
{
	if (o1 == o2)
	{
		return true;
	}
	else if ((o1 != null && o2 == null) || (o1 == null && o2 != null))
	{
		return false;
	}
	else if (typeof(o1) == "object")
	{
		if (typeof(o2) == "object")
		{
			for (var i in o1)
			{
				if (!this._areTheSame(o1[i], o2[i]))
				{
					return false;
				}
			}
			for (var i in o2)
			{
				if (!this._areTheSame(o1[i], o2[i]))
				{
					return false;
				}
			}
			return true;
		}
		else
		{
			return false;
		}
	}
	else if (typeof(o2) == "object")
	{
		return false
	}
	else
	{
		return false;
	}
}
