/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.cms.buttons.lock');

org.ametys.cms.buttons.lock.LockButton = function(id, configuration, pluginName) 
{
	org.ametys.cms.buttons.lock.LockButton.superclass.constructor.call(this, id, configuration, pluginName);
};

Ext.extend(org.ametys.cms.buttons.lock.LockButton, org.ametys.ribbon.control.button.ActionButton, {});

/**
 * @private
 * @property _lastParams The params received on the last refresh
 */
org.ametys.cms.buttons.lock.LockButton.prototype._lastParams;

/**
 * @private
 * @property {String[]} _currentContentsId The content id currently selected or null. 
 */
org.ametys.cms.buttons.lock.LockButton.prototype._currentContentsId;

/**
 * @private
 * @property {String[]} _currentLockedContentsId The content id currently selected and locked or null. 
 */
org.ametys.cms.buttons.lock.LockButton.prototype._currentLockedContentsId;

/**
 * @private
 * @property {String[]} _currentUnlockedContentsId The content id currently selected and unlocked or null. 
 */
org.ametys.cms.buttons.lock.LockButton.prototype._currentUnlockedContentsId;

/**
 * @private
 * @property {String[]} _currentLockedOwnerContentsId The content id currently selected and locked by current user or null. 
 */
org.ametys.cms.buttons.lock.LockButton.prototype._currentLockedOwnerContentsId;


org.ametys.cms.buttons.lock.LockButton.prototype.onMessage = function (messages)
{
	// SELECTION
	for (var i=messages.length - 1; i >= 0; i--)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
		{
			var targets = messages[i].getTargets();
			var allTargetsObject = org.ametys.messagebus.message.MessageTargetHelper.findAll(targets, this.checkTarget());
			var allTargets = this._convertToId(allTargetsObject);
			
			// No content selected
			if (allTargets.length == 0)
			{
				this.getElements().each(function(element) { element.setDisabled(true); });
				this.updateTooltip(this.getConfiguration()["default-description"]);
				
				this._currentContentsId = [];
			}
			else
			{
				this._currentEdition = allTargetsObject.length == 1 && allTargetsObject[0].getSubTargets().length > 0 && allTargetsObject[0].getSubTargets()[0].getType() == "form";;
				if (!this._areTheSame(this._currentContentsId, allTargets))
				{
					this._currentContentsId = allTargets;
					this.getElements().each(function(element) { element.refreshing(); element.setDisabled(true); });
					this.updateTooltip(this.getConfiguration()["default-description"]);
					var params = {targets: allTargets};
					this._setRefreshParams(params);
					org.ametys.ribbon.RibbonManager.getInstance().refreshElement('control', this, params);
				}
				else if (this._currentEdition)
				{
					// A single element selected, is it for edition ?
					this.updateTooltip(this.getConfiguration()["editing-description"]);
					this.getElements().each(function(element) { element.setDisabled(true); });
				}
			}
			
			return;
		}
		else if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_LOCKCHANGED)
		{
			var targets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, this.checkTarget());
			if (target != null)
			{
				if (this._isInSelection (this._currentContentsId, target.getParameters().id))
				{
					// Refresh
					this.getElements().each(function(element) { element.refreshing(); element.setDisabled(true); });
					this.updateTooltip(this.getConfiguration()["default-description"]);
					
					org.ametys.ribbon.RibbonManager.getInstance().refreshElement('control', this, {targets: this._currentContentsId});
				}
			}
		}
			
	}
}

org.ametys.cms.buttons.lock.LockButton.prototype._setRefreshParams = function (params)
{
}

org.ametys.cms.buttons.lock.LockButton.prototype._areTheSame = function (tab1, tab2)
{
	if (tab1 == tab2)
	{
		return true;
	}

	if (tab1 == null || tab2 == null || tab1.length != tab2.length)
	{
		return false;
	}	
	
	for (var i=0; i < tab1.length; i++)
	{
		if (tab2.indexOf(tab1[i]) == -1)
		{
			return false;
		}
	}
	
	return true;
}

org.ametys.cms.buttons.lock.LockButton.prototype._isInSelection = function (tab, elmt)
{
	if (tab == null || tab.length == 0)
	{
		return false;
	}	
	
	for (var i=0; i < tab.length; i++)
	{
		if (tab[i] == elmt)
		{
			return true;
		}
	}
	
	return false;
	
}

org.ametys.cms.buttons.lock.LockButton.prototype._convertToId = function (targets)
{
	var targetsIds = [];
	for (var i = 0; i < targets.length; i++)
	{
		targetsIds.push(targets[i].getParameters()['id']);
	}
	return targetsIds;
}
org.ametys.cms.buttons.lock.LockButton.prototype.checkTarget = function ()
{
	return function (target) { return target.getType() == 'content'; };
}

org.ametys.cms.buttons.lock.LockButton.prototype.configurationError = function(response)
{
	this.getElements().each(function(element) { element.stopRefreshing(); element.setDisabled(true); });
	this.updateTooltip(this.getConfiguration()["default-description"]);
}

org.ametys.cms.buttons.lock.LockButton.prototype.configurationChanged = function(params)
{
	this.getElements().each(function(element) { element.stopRefreshing(); });
	
	var tooltip = this._getTooltip("", params);
	
	var hasOneContent = tooltip.length > 0; 
	if (!hasOneContent)
	{
		tooltip += this.getConfiguration()['error-description'];
	}
	
	var toggleState = this._isToggle(params);
	this.getElements().each(function(element) { element.allowDepress = false; element.toggle(toggleState); });
	
	this._getIcon(params);
	this.getElements().each(function(element) { element.updateIcon(); });
	
	if (this._currentEdition)
	{
		this.getElements().each(function(element) { element.setDisabled(true); });
		tooltip = this.getConfiguration()["editing-description"];
	}
	else
	{
		var disabledState = this._isDisabled(params);
		this.getElements().each(function(element) { element.setDisabled(disabledState); });
	}
	
	this.updateTooltip(tooltip, this.getElements().get(0).iconLarge, null);
	
	this._lastParams = params;
}

org.ametys.cms.buttons.lock.LockButton.prototype._isToggle = function(params)
{
	var nbLocked = parseInt(params['locked-content-size']);
	var nbLockedOwner = parseInt(params['locked-owner-content-size']);
	
	if (nbLocked > 0 || nbLockedOwner > 0)
	{
		return true;
	}
	return false;
}

org.ametys.cms.buttons.lock.LockButton.prototype._isDisabled = function(params)
{
	var nbLocked = parseInt(params['locked-content-size']);
	var nbLockedOwner = parseInt(params['locked-owner-content-size']);
	
	if (nbLockedOwner == 0)
	{
		return true;
	}
	
	return false;
}

org.ametys.cms.buttons.lock.LockButton.prototype._getIcon = function(params)
{
	var nbLocked = parseInt(params['locked-content-size']);
	var nbLockedOwner = parseInt(params['locked-owner-content-size']);
	var nbLockedNotOwner = parseInt(params['locked-notowner-content-size']);
	var nbUnlocked = parseInt(params['unlocked-content-size']);
	
	nbLocked += nbLockedNotOwner;
	nbLockedOwner -= nbLockedNotOwner;
	
	if (nbUnlocked > 0 && nbLocked == 0 && nbLockedOwner == 0)
	{
		var iconSmall = context.contextPath + this.getConfiguration()['icon-small'];
		var iconLarge = context.contextPath + this.getConfiguration()['icon-medium'];
		this.getElements().each(
			function (element) 
			{
				element.iconSmall = iconSmall;
				element.iconLarge = iconLarge;
			}
		);
	}
	
	else if (nbLocked > 0 && nbLockedOwner == 0)
	{
		var iconSmall = context.contextPath + this.getConfiguration()['locked-content-icon-small'];
		var iconLarge = context.contextPath + this.getConfiguration()['locked-content-icon-medium'];
		this.getElements().each(
			function (element) 
			{
				element.iconSmall = iconSmall;
				element.iconLarge = iconLarge;
			}
		);
	}
	
	else if (nbLocked > 0 && nbLockedOwner > 0)
	{
		var iconSmall = context.contextPath + this.getConfiguration()['mixed-locked-content-icon-small'];
		var iconLarge = context.contextPath + this.getConfiguration()['mixed-locked-content-icon-medium'];
		this.getElements().each(
			function (element) 
			{
				element.iconSmall = iconSmall;
				element.iconLarge = iconLarge;
			}
		);
	}
	
	else if (nbLocked == 0 && nbLockedOwner > 0)
	{
		var iconSmall = context.contextPath + this.getConfiguration()['locked-owner-content-icon-small'];
		var iconLarge = context.contextPath + this.getConfiguration()['locked-owner-content-icon-medium'];
		this.getElements().each(
			function (element) 
			{
				element.iconSmall = iconSmall;
				element.iconLarge = iconLarge;
			}
		);
	}
}

org.ametys.cms.buttons.lock.LockButton.prototype._getTooltip = function(tooltip, params)
{
	this._currentLockedContentsId = [];
	this._currentUnlockedContentsId = [];
	this._currentLockedOwnerContentsId = [];
	
	var count = parseInt(params['locked-owner-content-size']);
	if (count > 0)
	{
		if (tooltip != "")
		{
			tooltip += "<br/><br/>";
		}
		
		tooltip += this.getConfiguration()["locked-owner-content-start-description"];
		for (var i=0; i < count; i++)
		{
			if (i != 0) 
			{
				tooltip += ", ";
			}
			tooltip += params["locked-owner-content-description-" + i];
			this._currentLockedOwnerContentsId.push(params["locked-owner-content-" + i]);
		}
		tooltip += this.getConfiguration()["locked-owner-content-end-description"];
	}
	
	var count = parseInt(params['locked-content-size']);
	if (count > 0)
	{
		if (tooltip != "")
		{
			tooltip += "<br/><br/>";
		}
		
		tooltip += this.getConfiguration()["locked-content-start-description"];
		for (var i=0; i < count; i++)
		{
			if (i != 0) 
			{
				tooltip += "<br/>";
			}
			tooltip += params["locked-content-description-" + i];
			this._currentLockedContentsId.push(params["locked-content-" + i]);
		}
		tooltip += this.getConfiguration()["locked-content-end-description"];
	}
	
	var count = parseInt(params['unlocked-content-size']);
	if (count > 0)
	{
		if (tooltip != "")
		{
			tooltip += "<br/><br/>";
		}
		
		tooltip += this.getConfiguration()["unlocked-content-start-description"];
		for (var i=0; i < count; i++)
		{
			if (i != 0) 
			{
				tooltip += ", ";
			}
			tooltip += params["unlocked-content-description-" + i];
			this._currentUnlockedContentsId.push(params["unlocked-content-" + i]);
		}
		tooltip += this.getConfiguration()["unlocked-content-end-description"];
	}
	
	return tooltip;
}


