/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.cms.editor.basicstyles');

/**
 * Bold the selection
 */
org.ametys.cms.editor.basicstyles.Bold = function() 
{
	tinyMCE.focus();
	tinyMCE.activeEditor.execCommand('Bold');
};
org.ametys.cms.editor.basicstyles.BoldSelectionListener = function(button, target, node)
{
	var off = target == null || node == null;

	var state = !off && org.ametys.cms.editor.basicstyles._testQueryCommandState(tinyMCE.activeEditor.queryCommandState("Bold"));
	button.getElements().each(
		function(element)
		{
			element.setDisabled(off);
			element.toggle(state);
		}
	);
}
org.ametys.cms.editor.basicstyles.BoldInitialize = function(id, configuration, pluginName)
{
	org.ametys.cms.editor.Editor.handleTag("strong").emptyTag = "-";
	org.ametys.cms.editor.Editor.handleTag("strong").replaceTags.push("b");
	org.ametys.cms.editor.Editor.handleTag("strong").replaceTags.push("strike");
	org.ametys.cms.editor.Editor.handleTag("strong").replaceTags.push("s");
}

/**
 * Italic the selection
 */
org.ametys.cms.editor.basicstyles.Italic = function() 
{
	tinyMCE.focus();
	tinyMCE.activeEditor.execCommand('Italic');
};
org.ametys.cms.editor.basicstyles.ItalicSelectionListener = function(button, target, node)
{
	var off = target == null || node == null;
	
	var state = !off && org.ametys.cms.editor.basicstyles._testQueryCommandState(tinyMCE.activeEditor.queryCommandState("Italic"));
	button.getElements().each(
		function(element)
		{
			element.setDisabled(off);
			element.toggle(state);
		}
	);
}
org.ametys.cms.editor.basicstyles.ItalicInitialize = function(id, configuration, pluginName)
{
	org.ametys.cms.editor.Editor.handleTag("em").emptyTag = "-";
	org.ametys.cms.editor.Editor.handleTag("em").replaceTags.push("i");
	org.ametys.cms.editor.Editor.handleTag("em").replaceTags.push("u");
}

/**
 * Indent text
 */
org.ametys.cms.editor.basicstyles.Indent = function ()
{
	tinyMCE.focus();
	tinyMCE.activeEditor.execCommand('Indent');
	//tinyMCE.activeEditor.execCommand('mceCleanup');
}
org.ametys.cms.editor.basicstyles.IndentSelectionListener = function(button, target, node)
{
	var off = target == null || node == null;
	var on = false;
	
	if (!off && tinyMCE.activeEditor != null)
	{
		// check that we are in a list (ordered or not)
		on = org.ametys.cms.editor.basicstyles._testQueryCommandState(tinyMCE.activeEditor.queryCommandState("InsertUnorderedList")) || org.ametys.cms.editor.basicstyles._testQueryCommandState(tinyMCE.activeEditor.queryCommandState("InsertOrderedList"));
		if (on)
		{
			on = false;
			
			// check that we are in a nested list
			var parentList = tinyMCE.activeEditor.dom.getParent(tinyMCE.activeEditor.selection.getNode(), function(node) { return /^li$/i.test(node.tagName) } );
			if (parentList != null)
			{
				var prev = Ext.get(parentList).prev("li");
				on = prev != null;
			}
		}
	}
	button.getElements().each(function(element) {element.setDisabled(off || !on);})
}

/**
 * Outdent text
 */
org.ametys.cms.editor.basicstyles.Outdent = function ()
{
	tinyMCE.focus();
	tinyMCE.activeEditor.execCommand('Outdent');
	//tinyMCE.activeEditor.execCommand('mceCleanup');
}
org.ametys.cms.editor.basicstyles.OutdentSelectionListener = function(button, target, node)
{
	var off = target == null || node == null;
	var on = false;
	
	if (!off && tinyMCE.activeEditor != null)
	{
		// check that we are in a list (ordered or not)
		on = org.ametys.cms.editor.basicstyles._testQueryCommandState(tinyMCE.activeEditor.queryCommandState("InsertUnorderedList")) || org.ametys.cms.editor.basicstyles._testQueryCommandState(tinyMCE.activeEditor.queryCommandState("InsertOrderedList"));
		if (on)
		{
			// check that we are in a nested list
			var parentList = tinyMCE.activeEditor.dom.getParent(tinyMCE.activeEditor.selection.getNode(), function(node) { return /^ul|ol$/i.test(node.tagName) } );
			on = tinyMCE.activeEditor.dom.getParent(parentList.parentNode, function(node) { return /^ul|ol$/i.test(node.tagName) } ) != null;
		}
	}
	button.getElements().each(function(element) {element.setDisabled(off || !on);})
}

/**
 * Insert list
 */
org.ametys.cms.editor.basicstyles.ListMenu = function(id, configuration, pluginName)
{
	org.ametys.cms.editor.Editor.handleTag("li").emptyTag = "-";
	org.ametys.cms.editor.Editor.handleTag("li").replaceTags.push("dd");
	org.ametys.cms.editor.Editor.handleTag("li").replaceTags.push("dt");
	org.ametys.cms.editor.Editor.handleTag("li").handleAttribute("style");
	
	var tag = org.ametys.cms.editor.Editor.handleTag(configuration["tagname"]);
	tag.emptyTag = "-";
	if (configuration["replaceTag"] != null)
	{
		org.ametys.cms.editor.Editor.handleTag(configuration["tagname"]).replaceTags.push(configuration["replaceTag"]);
	}
	tag.handleAttribute("class").defaultValue = configuration["gallery-" + configuration["defaultindex"] + "-css-class"];
	
	var galleryCount = parseInt(configuration["gallery-size"]); 
	for (var i=0;  i < galleryCount; i++)
	{
		if (configuration["gallery-" + i + "-css-class"] != null)
		{
			tag.handleAttribute("class").values.push(configuration["gallery-" + i + "-css-class"]);
		}
	}	
	
	org.ametys.cms.editor.basicstyles.ListMenu.superclass.constructor.call(this, id, configuration, pluginName);
}

Ext.extend(org.ametys.cms.editor.basicstyles.ListMenu, org.ametys.cms.ribbon.button.EditorMenu, {});


org.ametys.cms.editor.basicstyles.List = function (id, conf, pluginname)
{
	var li = tinyMCE.activeEditor != null ? tinyMCE.activeEditor.dom.getParent(tinyMCE.activeEditor.selection.getNode(), 'li') : null;
	
	if (li != null && conf["tagname"] == li.parentNode.tagName.toLowerCase())
	{
		tinyMCE.focus();
		tinyMCE.activeEditor.execCommand(/ul/i.test(conf['tagname']) ? 'InsertUnorderedList' : 'InsertOrderedList');
	}
	else
	{
		org.ametys.cms.editor.basicstyles.ListApplyStyle({}, conf);
	}
}
org.ametys.cms.editor.basicstyles.ListListener = function(button, target, node)
{
	var off = target == null || node == null || tinyMCE.activeEditor == null;
	if (off)
	{
		button.getElements().each(function(element) {element.setDisabled(true); element.toggle(false) })
	}
	else
	{
		var li = tinyMCE.activeEditor.dom.getParent(tinyMCE.activeEditor.selection.getNode(), 'li');
		
		button.getElements().each(
			function (element) 
			{
				element.setDisabled(false);
				element.toggle(li != null && button.getConfiguration()["tagname"] == li.parentNode.tagName.toLowerCase());
			} 
		);
	}
}
org.ametys.cms.editor.basicstyles.ListInitialize = function(id, configuration, pluginName)
{
	org.ametys.cms.editor.Editor.handleTag("em").emptyTag = "-";
	org.ametys.cms.editor.Editor.handleTag("em").replaceTags.push("i");
	org.ametys.cms.editor.Editor.handleTag("em").replaceTags.push("u");
}

org.ametys.cms.editor.basicstyles.RemoveList = function (button)
{
	if (tinyMCE.activeEditor != null)
	{
		var li = tinyMCE.activeEditor.dom.getParent(tinyMCE.activeEditor.selection.getNode(), 'li');
		if (li != null)
		{
			tinyMCE.focus();
			tinyMCE.activeEditor.execCommand(/ul/i.test(button.ribbonControl.getConfiguration()['tagname']) ? 'InsertUnorderedList' : 'InsertOrderedList');
		}
	}
}
org.ametys.cms.editor.basicstyles.RemoveListListener = function(button)
{
	var off = tinyMCE.activeEditor == null;
	if (off)
	{
		button.setDisabled(true);
		button.toggle(false);
	}
	else
	{
		var li = tinyMCE.activeEditor.dom.getParent(tinyMCE.activeEditor.selection.getNode(), 'li');
		
		button.setDisabled(false);
		button.toggle(li == null || li.parentNode.tagName.toLowerCase() != button.ribbonControl.getConfiguration()['tagname'].toLowerCase());
	}
}

org.ametys.cms.editor.basicstyles.ListApplyStyle = function(button, configuration) 
{
	var conf = button.ribbonControl ? button.ribbonControl.getConfiguration() : configuration;
	var index = button.index != null ? button.index : conf['defaultindex'];
	var node = tinyMCE.activeEditor.dom.getParent(tinyMCE.activeEditor.selection.getNode(), conf['tagname']);

	tinyMCE.focus();
	tinyMCE.activeEditor.execCommand('mceBeginUndoLevel');

	if (node == null)
	{
		tinyMCE.activeEditor.execCommand(/ul/i.test(conf['tagname']) ? 'InsertUnorderedList' : 'InsertOrderedList');
		node = tinyMCE.activeEditor.dom.getParent(tinyMCE.activeEditor.selection.getNode(), conf['tagname']);
		
		if (node == null)
		{
			// may happen when the selection is around the text
			// CMS-2483 Problem when creating square list on pasted text
			tinyMCE.activeEditor.selection.collapse();
			var isThatNode = tinyMCE.activeEditor.selection.getNode().previousSibling;
			node = /^ul|ol$/i.test(isThatNode.tagName) ? isThatNode : null;
		}
	}
	if (node != null)
	{
		node.setAttribute("class", conf["gallery-" + index + "-css-class"]);
	}

	tinyMCE.activeEditor.execCommand('mceEndUndoLevel');
}
org.ametys.cms.editor.basicstyles.ListStyleListener = function(item)
{
	var index = item.index;
	
	var targets = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
	var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "node";});
	var node = target != null ? target.getParameters()['object'] : null;

	if (node != null && tinyMCE.activeEditor != null)
	{
		item.setDisabled(false);

		var specificNode = tinyMCE.activeEditor.dom.getParent(node, item.ribbonControl.getConfiguration()['tagname']);
		if (specificNode != null)
		{
			item.toggle(specificNode.className.split(" ").indexOf(item.ribbonControl.getConfiguration()["gallery-" + index + "-css-class"]) >= 0);
			
			return;
		}
	}
	else
	{
		item.setDisabled(true);
	}
	item.toggle(false);
}


/**
 * Sup
 */
org.ametys.cms.editor.basicstyles.Sup = function ()
{
	tinyMCE.focus();
	tinyMCE.activeEditor.execCommand('SuperScript');
}
org.ametys.cms.editor.basicstyles.SupSelectionListener = function(button, target, node)
{
	var off = target == null || node == null;
	
	button.getElements().each(
		function(element) 
		{
			element.setDisabled(off);
			element.toggle(!off && org.ametys.cms.editor.basicstyles._testQueryCommandState(tinyMCE.activeEditor.queryCommandState("SuperScript")));
		}
	);
}
org.ametys.cms.editor.basicstyles.SupInitialize = function(id, configuration, pluginName)
{
	org.ametys.cms.editor.Editor.handleTag("sup").emptyTag = "-";
}

/**
 * Sub
 */
org.ametys.cms.editor.basicstyles.Sub = function ()
{
	tinyMCE.focus();
	tinyMCE.activeEditor.execCommand('SubScript');
}
org.ametys.cms.editor.basicstyles.SubSelectionListener = function(button, target, node)
{
	var off = target == null || node == null;
	
	button.getElements().each(
		function(element) 
		{
			element.setDisabled(off);
			element.toggle(!off && org.ametys.cms.editor.basicstyles._testQueryCommandState(tinyMCE.activeEditor.queryCommandState("SubScript")));
		}
	);
}
org.ametys.cms.editor.basicstyles.SubInitialize = function(id, configuration, pluginName)
{
	org.ametys.cms.editor.Editor.handleTag("sub").emptyTag = "-";
}

/**
 * Align text to the left
 */
org.ametys.cms.editor.basicstyles.AlignLeft = function ()
{
	tinyMCE.focus();
	tinyMCE.activeEditor.execCommand('JustifyLeft');
}
org.ametys.cms.editor.basicstyles.AlignLeftSelectionListener = function(button, target, node)
{
	var off = target == null || node == null;

	button.getElements().each(
		function(element) 
		{
			element.setDisabled(off);
			element.toggle(!off && org.ametys.cms.editor.basicstyles._testQueryCommandState(tinyMCE.activeEditor.queryCommandState("JustifyLeft")));
		}
	);
}
org.ametys.cms.editor.basicstyles.AlignLeftInitialize = function(id, configuration, pluginName)
{
	org.ametys.cms.editor.Editor.handleTag("p").handleAttribute("style")
}

/**
 * Align text to the center
 */
org.ametys.cms.editor.basicstyles.AlignCenter = function ()
{
	tinyMCE.focus();
	tinyMCE.activeEditor.execCommand('JustifyCenter');
}
org.ametys.cms.editor.basicstyles.AlignCenterSelectionListener = function(button, target, node)
{
	var off = target == null || node == null;
	
	button.getElements().each(
		function(element) 
		{
			element.setDisabled(off);
			element.toggle(!off && org.ametys.cms.editor.basicstyles._testQueryCommandState(tinyMCE.activeEditor.queryCommandState("JustifyCenter")));
		}
	);
}
org.ametys.cms.editor.basicstyles.AlignCenterInitialize = function(id, configuration, pluginName)
{
	org.ametys.cms.editor.Editor.handleTag("p").handleAttribute("style")
}

/**
 * Align text to the right
 */
org.ametys.cms.editor.basicstyles.AlignRight= function ()
{
	tinyMCE.focus();
	tinyMCE.activeEditor.execCommand('JustifyRight');
}
org.ametys.cms.editor.basicstyles.AlignRightSelectionListener = function(button, target, node)
{
	var off = target == null || node == null;
	
	button.getElements().each(
		function(element) 
		{
			element.setDisabled(off);
			element.toggle(!off && org.ametys.cms.editor.basicstyles._testQueryCommandState(tinyMCE.activeEditor.queryCommandState("JustifyRight")));
		}
	);
}
org.ametys.cms.editor.basicstyles.AlignRightInitialize = function(id, configuration, pluginName)
{
	org.ametys.cms.editor.Editor.handleTag("p").handleAttribute("style")
}

/**
 * Align text to the right
 */
org.ametys.cms.editor.basicstyles.AlignJustify = function ()
{
	tinyMCE.focus();
	tinyMCE.activeEditor.execCommand('JustifyFull');
}
org.ametys.cms.editor.basicstyles.AlignJustifySelectionListener = function(button, target, node)
{
	var off = target == null || node == null;
	
	button.getElements().each(
		function(element) 
		{
			element.setDisabled(off);
			element.toggle(!off && org.ametys.cms.editor.basicstyles._testQueryCommandState(tinyMCE.activeEditor.queryCommandState("JustifyFull")));
		}
	);
}
org.ametys.cms.editor.basicstyles.AlignJustifyInitialize = function(id, configuration, pluginName)
{
	org.ametys.cms.editor.Editor.handleTag("p").handleAttribute("style")
}

/**
 * @private
 * test the result of a queryCommandState that can be true/false/undefined/Object
 */
org.ametys.cms.editor.basicstyles._testQueryCommandState = function(state)
{
	return state != undefined && state != false;
}

