/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.cms.editor');

/**
 * An element of the htmlexpert toolbar. This is an abstract class.
 * @param {String} id The unique element identifier
 * @param {Map<id, value>} configuration The configuration of the element instance.
 * @param {String} The name of the plugin where the element was declared
 * @constructor
 */
org.ametys.cms.editor.HTMLExpertToolbarButton = function(id, configuration, pluginName)
{
	this._id = id;
	this._configuration = configuration;
	this._pluginName = pluginName;
}

/**
 * @property {String} _id The identifier of the element.
 * @private
 */
org.ametys.cms.editor.HTMLExpertToolbarButton.prototype._id;
/**
 * Get the identifier of the element.
 * @return {String} The unique identifier of the control.
 */
org.ametys.cms.editor.HTMLExpertToolbarButton.prototype.getId = function()
{
	return this._id;
}

/**
 * @private
 * @property {String} _pluginName The name of the plugin that declares the element
 */
org.ametys.cms.editor.HTMLExpertToolbarButton.prototype._pluginName;
/**
 * Get the plugin name that declared the element
 * @return {String} The name of the plugin that declared this element. Can not be null or empty.
 */
org.ametys.cms.editor.HTMLExpertToolbarButton.prototype.getPluginName = function()
{
	return this._pluginName;
}

/**
 * @private
 * @property {Map<id, value>} _configuration The configuration of the element instance.
 */
org.ametys.cms.editor.HTMLExpertToolbarButton.prototype._configuration;
/**
 * Get the configuration used at creation time. 
 * @return {Map<id, value>} The configuration of the control instance. Can not be null.
 */
org.ametys.cms.editor.HTMLExpertToolbarButton.prototype.getConfiguration = function()
{
	return this._configuration;
}

/**
 * This method is call once. Implement this method to create the control in the toolbar.
 * @return {Ext.form.field} The control created. Ready to be added to the toolbar.
 */
org.ametys.cms.editor.HTMLExpertToolbarButton.createControl = function()
{
	throw "HTMLExpertToolbarButton.createControl method has to be implemented";
}