/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.cms.editor');

/**
 * This widget list the possible styles for para.
 * It is based upon a special configuration given by the ParaStyleCliendSideElement
 * &lt;ul&gt;
 * 		&lt;li&gt;style-count&lt;/li&gt;
 * 		&lt;li&gt;style-I-button-label&lt;/li&gt;
 * 		&lt;li&gt;style-I-button-description&lt;/li&gt;
 * 		&lt;li&gt;style-I-button-cssclass&lt;/li&gt;
 * 		&lt;li&gt;style-I-inline-editor-render&lt;/li&gt;
 * &lt;/ul&gt;
 * This implementation do not use the configuration parameter "style-I-button-icon"
 */
org.ametys.cms.editor.StyleList = function(id, configuration, pluginName)
{
	org.ametys.cms.editor.StyleList.superclass.constructor.call(this, id, configuration, pluginName);
}

Ext.extend(org.ametys.cms.editor.StyleList, org.ametys.cms.control.ComboBoxField, {});

org.ametys.cms.editor.StyleList.prototype.createStore = function()
{
	var data = new Array();
	for (var i = 0; i < parseInt(this.getConfiguration()['style-count']); i++)
	{
		var buttonLabel = this.getConfiguration()['style-' + i + '-button-label'];
		var buttonDescription = this.getConfiguration()['style-' + i + '-button-description'];
		var buttonCSSClass = this.getConfiguration()['style-' + i + '-button-cssclass'];
		var inlineEditorRender = this.getConfiguration()['style-' + i + '-inline-editor-render'];

		var inlineEditorTagName = null;
		var inlineEditorCSSClass = null;
		
		var index = inlineEditorRender.indexOf(".");
		if (index == -1)
		{
			inlineEditorTagName = inlineEditorRender;
		}
		else
		{
			inlineEditorTagName = inlineEditorRender.substring(0, index);
			inlineEditorCSSClass = inlineEditorRender.substring(index + 1);
		}

		var t = org.ametys.cms.editor.Editor.handleTag(inlineEditorTagName);
		if (inlineEditorTagName == "p")
		{
			t.emptyTag = "#";
			t.replaceTags.push("address");
			t.replaceTags.push("pre");
		}
		else
		{
			t.emptyTag = "-";
		}

		if (inlineEditorCSSClass != null)
		{
			if (t.attributes["class"] == null)
			{
				t.handleAttribute("class").defaultValue = inlineEditorCSSClass;
			}
			t.handleAttribute("class").values.push(inlineEditorCSSClass);
		}
		else
		{
			t.handleAttribute("class").defaultValue = null;
		}
		
		data.push([Ext.id(), buttonLabel, buttonDescription, buttonCSSClass, inlineEditorTagName, inlineEditorCSSClass != null ? inlineEditorCSSClass : '']);
	}
	
	var store = new Ext.data.SimpleStore({
        id: 0,
        fields: [
            'id',
            'text',
            'description',
            'cls',
            'tagName',
            'style'
        ],
        data: data
    });
	
	return store;
}

org.ametys.cms.editor.StyleList._applyStyle = function (combo, record, index)
{
	tinyMCE.focus();
	
	tinyMCE.activeEditor.execCommand('mceBeginUndoLevel');
	tinyMCE.activeEditor.execCommand('FormatBlock', false, record.data.tagName);

	var selectedBlocks = tinyMCE.activeEditor.selection.getSelectedBlocks();
	for (var i = 0; i < selectedBlocks.length; i++)
	{
		var block = selectedBlocks[i];
		var selectionParentNode = tinyMCE.activeEditor.dom.getParent(block, record.data.tagName);
		
		if (selectionParentNode != null)
		{
			if (record.data.style != '')
			{
				// remove existing classes
				for (var k = 0; k < combo.getStore().getCount(); k++)
				{
					var e = combo.getStore().getAt(k); 
					if (e.get("tagName") == record.data.tagName && tinyMCE.activeEditor.dom.addClass(selectionParentNode, e.get("style")))
					{
						tinyMCE.activeEditor.dom.removeClass(selectionParentNode, e.get("style"));
					}
				}
				tinyMCE.activeEditor.dom.addClass(selectionParentNode, record.data.style);
			}
			else
			{
				selectionParentNode.className = "";
			}
		}
	}
	tinyMCE.activeEditor.execCommand('mceEndUndoLevel');
}

org.ametys.cms.editor.StyleSelectionListener = function(combo, target, node)
{
	var off = target == null || node == null;
	if (off)
	{
		combo.getElements().each(function(element) {element.setDisabled(true);});
		return;
	}
	
	combo.getElements().each(
		function(element) 
		{
			element.setDisabled(false);

			var records = element.getStore().queryBy(org.ametys.cms.editor.StyleSelectionListener._testStyle, node);
			if (records.getCount() == 1)
			{
				element.setValue(records.get(0).data.id);
			}
			else if (records.getCount() > 1)
			{
				var i = 0;
				if (records.get(0).data.style == '')
				{
					i = 1;
				}
				
				element.setValue(records.get(i).data.id);
			}
		}
	);
}

org.ametys.cms.editor.StyleSelectionListener._testStyle = function(record, id)
{
	var className = (record.data.style != null && record.data.style != "") ? '.' + record.data.style : '';
	var node = tinyMCE.activeEditor.dom.getParent(this, record.data.tagName + className);
	return node != null;  
}
