/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.ribbon.control.button');

/**
 * Create the control instance.
 * @param {String} id The unique identifier
 * @param {Map<id, value>} configuration The configuration of the control instance.
 * @param {String} pluginName The name of the declaring plugin
 * @class This class implements the behavior for an action.
 * @extends org.ametys.ribbon.control.button.ActionSelectionButton
 */
org.ametys.ribbon.control.button.NotOpenedContentActionButton = function(id, configuration, pluginName)
{
	org.ametys.ribbon.control.button.NotOpenedContentActionButton.superclass.constructor.call(this, id, configuration, pluginName);
}

Ext.extend(org.ametys.ribbon.control.button.NotOpenedContentActionButton, org.ametys.ribbon.control.button.ActionSelectionButton, {});

/**
 * Creates the toggle button
 * @param {integer} colspan The configured colspan. Must be transmitted to the control.
 * @return {Ext.form.field} The toggle button created. 
 */
org.ametys.ribbon.control.button.NotOpenedContentActionButton.prototype.onMessage = function(messages)
{
	for (var i=0; i < messages.length; i++)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
		{
			var targets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, this._testTarget.createDelegate(this));
			
			if (target != null)
			{
			    // A content is selected: enable the button if its tool is closed.
				var toolOpened = org.ametys.uitool.ToolsManager.getInstance().getTool('content-' + target.getParameters().id) != null;
				this.getElements().each(function(element) { element.setDisabled(toolOpened); });
			}
			else
			{
			    // No content selected: disable the button.
				this.getElements().each(function(element) { element.disable(); });
			}
		}
	}
}
