/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.cms.ribbon.button');

org.ametys.cms.ribbon.button.SmartContentButton = function(id, configuration, pluginName) 
{
	org.ametys.cms.ribbon.button.SmartContentButton.superclass.constructor.call(this, id, configuration, pluginName);
};

Ext.extend(org.ametys.cms.ribbon.button.SmartContentButton, org.ametys.ribbon.control.button.ActionButton, {});

/**
 * @private
 * @property {Map<String, String>} _lastParams The params received on the last refresh
 */
org.ametys.cms.ribbon.button.SmartContentButton.prototype._lastParams;

/**
 * @private
 * @property {String[]} _currentContentsId The content id currently selected or null. 
 */
org.ametys.cms.ribbon.button.SmartContentButton.prototype._currentContentsId;

org.ametys.cms.ribbon.button.SmartContentButton.prototype._areTheSame = function (tab1, tab2)
{
	if (tab1 == tab2)
	{
		return true;
	}

	if (tab1 == null || tab2 == null || tab1.length != tab2.length)
	{
		return false;
	}	
	
	for (var i=0; i < tab1.length; i++)
	{
		if (tab2.indexOf(tab1[i]) == -1)
		{
			return false;
		}
	}
	
	return true;
}

org.ametys.cms.ribbon.button.SmartContentButton.prototype.onMessage = function (messages)
{
	// SELECTION
	for (var i=messages.length - 1; i >= 0; i--)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
		{
			var targets = messages[i].getTargets();
			var allTargets = this._convertToId(org.ametys.messagebus.message.MessageTargetHelper.findAll(targets, this.checkTarget()));
			
			// No content selected
			if (allTargets.length == 0)
			{
				this.getElements().each(function(element) { element.setDisabled(true); });
				this.updateTooltip(this.getConfiguration()["default-description"]);
				
				this._currentContentsId = [];
			}
			// A single target selected or multiselection is enabled
			else if (allTargets.length == 1 || this.getConfiguration()["enable-multiselection"] == "true")
			{
				if (!this._areTheSame(this._currentContentsId, allTargets))
				{
					this._currentContentsId = allTargets;
				
					this.getElements().each(
						function(element) 
						{ 
							element.setDisabled(true);
							element.toggle(false);
							element.refreshing();
						}
					);

					this.updateTooltip(this.getConfiguration()["refresh-description"]);
					org.ametys.ribbon.RibbonManager.getInstance().refreshElement('control', this, {targets: allTargets});
				}
			}
			// Too many content selected
			else
			{
				this.getElements().each(function(element) { element.setDisabled(true); });
				this.updateTooltip(this.getConfiguration()["multiselection-disabled-description"]);
				
				this._currentContentsId = [];
			}
			
			break;
		}
	}
	
	// WORKFLOW
	for (var i=0; i < messages.length; i++)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_WORKFLOWCHANGED
			|| messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_WORKFLOWCHANGING
			|| messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_LOCKCHANGED)
		{
			var targets = messages[i].getTargets();
			var allTargets = this._convertToId(org.ametys.messagebus.message.MessageTargetHelper.findAll(targets, this.checkTarget()));
			
			var currentSelection = org.ametys.ribbon.RibbonManager.getInstance().getCurrentSelectionTargets();
			var currentSelectionIds = this._convertToId(org.ametys.messagebus.message.MessageTargetHelper.findAll(currentSelection, this.checkTarget()));
			
			// No content selected
			if (currentSelectionIds.length == 0)
			{
				continue;
			}
			// A single target selected or multiselection is enabled
			else if (currentSelectionIds.length == 1 || this.getConfiguration()["enable-multiselection"] == "true")
			{
				var stop = false;
				for (var t=0; !stop && t < allTargets.length; t++)
				{
					for (var c=0; !stop && c < currentSelectionIds.length; c++)
					{
						if (currentSelectionIds[c] == allTargets[t])
						{
							this.getElements().each(
								function(element) 
								{ 
									element.setDisabled(true);
									element.toggle(false);
									element.refreshing();
								}
							);
							this.updateTooltip(this.getConfiguration()["refresh-description"]);
							if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_WORKFLOWCHANGED
						        || messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_LOCKCHANGED)
							{
								org.ametys.ribbon.RibbonManager.getInstance().refreshElement('control', this, {targets: currentSelectionIds});
							}

							stop = true;
						}
					}
				}
			}
			// Too many content selected
			else
			{
				continue;
			}			
		}
	}
}

org.ametys.cms.ribbon.button.SmartContentButton.prototype._convertToId = function (targets)
{
	var targetsIds = [];
	for (var i = 0; i < targets.length; i++)
	{
		targetsIds.push(targets[i].getParameters()['id']);
	}
	return targetsIds;
}
org.ametys.cms.ribbon.button.SmartContentButton.prototype.checkTarget = function ()
{
	return function (target) { return target.getType() == 'content'; };
}

org.ametys.cms.ribbon.button.SmartContentButton.prototype._handlingMultiple = function(tooltip, paramPrefix, params)
{
	var count = parseInt(params[paramPrefix + "-content-size"]);
	if (count > 0)
	{
		if (tooltip != "")
		{
			tooltip += "<br/><br/>";
		}
		
		tooltip += this.getConfiguration()[paramPrefix + "-start-description"];
		for (var i=0; i < count; i++)
		{
			if (i != 0) 
			{
				tooltip += ", ";
			}
			tooltip += params[paramPrefix + "-content-" + i];
		}
		tooltip += this.getConfiguration()[paramPrefix + "-end-description"];
	}
	
	return tooltip;
}

org.ametys.cms.ribbon.button.SmartContentButton.prototype.configurationError = function(response)
{
	this.getElements().each(
		function(element) 
		{ 
			element.setDisabled(true);
			element.stopRefreshing();
		}
	);
	this.updateTooltip(this.getConfiguration()["default-description"]);
}

org.ametys.cms.ribbon.button.SmartContentButton.prototype.configurationChanged = function(params)
{
	this.getElements().each(function(element) { element.stopRefreshing(); });

	var tooltip = this._handlingMultiple("", "allright", params);
	
	var hasOneContent = tooltip.length > 0; 
	if (!hasOneContent)
	{
		tooltip += this.getConfiguration()['error-description'];
	}
	
	tooltip = this._handlingMultiple(tooltip, "locked", params);
	tooltip = this._handlingMultiple(tooltip, "noright", params);
	tooltip = this._handlingMultiple(tooltip, "nomodifiable", params);
	tooltip = this._handlingMultiple(tooltip, "workflowaction", params);
	tooltip = this._handlingMultiple(tooltip, "workflowstep", params);
	
	var toggleState = hasOneContent && this.getConfiguration()["enable-toggle"] == "true";
	this.getElements().each(
		function(element) 
		{ 
			element.allowDepress = false;
			element.setDisabled(!hasOneContent);
			element.toggle(toggleState);
		}
	);
	
	this.updateTooltip(tooltip);
	this._lastParams = params;
}
