/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.cms.ribbon.tab');

org.ametys.cms.ribbon.tab.ContentTab = function(id, configuration, pluginName, tabPanel) 
{
	org.ametys.cms.ribbon.tab.ContentTab.superclass.constructor.call(this, id, configuration, pluginName, tabPanel);
	
	if (configuration['content-type'] != null)
	{
		this._cTypeRegExp = new RegExp(configuration['content-type']);
		// Add content type(s) to the global list
		org.ametys.cms.ribbon.tab.ContentTab._cTypes.push (this._cTypeRegExp);
	}
}

/**
 * @static
 * @property {Array} The list of content types handled by their own ContentTab
 */
org.ametys.cms.ribbon.tab.ContentTab._cTypes = [];

Ext.extend(org.ametys.cms.ribbon.tab.ContentTab, org.ametys.cms.ribbon.tab.SelectionTab, {});

/**
 * @private
 * @property {RegExp} _cTypeRegExp The content type of the target lookup
 */
org.ametys.cms.ribbon.tab.ContentTab.prototype._cTypeRegExp;

/**
 * @private
 * @property {Array} _excludedContentTypes The list of excluded content types
 */
org.ametys.cms.ribbon.tab.ContentTab.prototype._excludedContentTypes = [];

/**
 * @private
 * Test a target. Does it match ?
 * @return {org.ametys.messagebus.message.MessageTarget} The target to check
 */
org.ametys.cms.ribbon.tab.ContentTab.prototype._testTarget = function(target)
{
	var matchSelection = org.ametys.cms.ribbon.tab.ContentTab.superclass._testTarget.call(this, target);
	if (!matchSelection)
	{
		return false;
	}
	
	var cType = target.getParameters().type;
	if (this._cTypeRegExp != null)
	{
		return this._cTypeRegExp.test(cType);
	}

	for (var i=0; i < org.ametys.cms.ribbon.tab.ContentTab._cTypes.length; i++)
	{
		if (org.ametys.cms.ribbon.tab.ContentTab._cTypes[i].test(cType))
		{
			// The content is handled by another ContentTab
			return false;
		}
	}
	
	return true;
}