/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.cms.tool.content');

/**
 * Do not call this constructor. Declared to and used by the {@see org.ametys.uitool.ToolsManager}
 * @constructor
 * @extends org.ametys.uitool.tool.ToolFactory
 * @class The factory to creates old content tools.
 * @param {String} id The unique id of the factory
 * @param {Map} config Options are : 'default-location' : where to place the tool; 'description' : the tooltip to display with following parameters 'siteUrl', 'siteTitle', 'lang', 'contentName'.
 * @param {String} pluginName The name of the plugin where the factory was declared
 */
org.ametys.cms.tool.content.OldContentToolFactory = function(id, config, pluginName) 
{
	org.ametys.cms.tool.content.OldContentToolFactory.superclass.constructor.call(this, id, config, pluginName);
};

Ext.extend(org.ametys.cms.tool.content.OldContentToolFactory, org.ametys.uitool.tool.ToolFactory, {});

/**
 * The prefix used to generate the tool id.
 * @type {String} 
 * @private
 * @constant
 */
org.ametys.cms.tool.content.OldContentToolFactory._toolIdPrefix = "old-content-";

/**
 * Creates a tool of type {@see org.ametys.cms.tool.content.OldContentTool} or activate the existing one.
 * There is one tool per old content.
 * @param {Map} params The params used by the factory are : 'id' that is the old content id. Params are transmited the the old content tool : {@see org.ametys.cms.tool.content.OldContentTool#setParams}
 * @return {Ext.org.ametys.uitool.tool.Tool} The tool to open.
 */
org.ametys.cms.tool.content.OldContentToolFactory.prototype.openTool = function (params)
{
	if (org.ametys.uitool.ToolsManager.getInstance().getTool(org.ametys.cms.tool.content.OldContentToolFactory._toolIdPrefix + params.id) == null)
	{
		// Tool does not exists => Tool creation
		var descTpl = new Ext.Template(this._config['description']);
		
		this._config['title'] = params.id;
		var tool = new org.ametys.cms.tool.content.OldContentTool (org.ametys.cms.tool.content.OldContentToolFactory._toolIdPrefix + params.id, this.getPluginName());
		
		tool.setConfiguration(this._config);
		tool.setFactory (this);
		
		var values = {'siteUrl' : '', 'siteTitle' : '', 'lang': '', 'contentName' : params.id};
		tool.setTooltip (null, null, descTpl.applyTemplate(values), null);
		
		org.ametys.uitool.ToolsManager.getInstance().addUITool (tool, this._config['default-location']);
	}
	else
	{
		// Tool does already exists => Tool activation
		tool = org.ametys.uitool.ToolsManager.getInstance().getTool(org.ametys.cms.tool.content.OldContentToolFactory._toolIdPrefix + params.id);
	}

	tool.setParams(params);
	tool.activate();

	return tool;
}

/**
 * Destroy the tool.
 * @param {org.ametys.uitool.tool.Tool} tool The tool to close.
 */
org.ametys.cms.tool.content.OldContentToolFactory.prototype.closeTool = function (tool)
{
	org.ametys.uitool.ToolsManager.getInstance().removeUITool (tool);
}
