/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.cms.tool.right.control');

org.ametys.cms.tool.right.control.RightsAssignmentToolButton = function(id, configuration, pluginName)
{
	org.ametys.cms.tool.right.control.RightsAssignmentToolButton.superclass.constructor.call(this, id, configuration, pluginName);
}

Ext.extend(org.ametys.cms.tool.right.control.RightsAssignmentToolButton, org.ametys.ribbon.control.button.ToolButton, {});

org.ametys.cms.tool.right.control.RightsAssignmentToolButton.prototype._onPress = function(button, state)
{
	if (button.pressed)
	{
		// Close the tool
		var control = org.ametys.ribbon.RibbonManager.getInstance().getControls()[this.controlId];
		var tool = org.ametys.uitool.ToolsManager.getInstance().getTool(control.getConfiguration()['role']);
		
		if (tool == null)
			return;
		
		tool.close();
		control.getElements().each(function(element){ element.toggle(false); });
	}
	else
	{
		org.ametys.cms.tool.right.control.RightsAssignmentToolButton.superclass._onPress.call(this, button, state);
	}
}

org.ametys.cms.tool.right.control.RightsAssignmentToolButton.prototype.onMessage = function(messages)
{
	for (var i=0; i < messages.length; i++)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_TOOLSTATECHANGED 
				|| messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_TOOLOPENED 
				|| messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_TOOLFOCUSES)
		{
			var targets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "tool"});
			if (target.getParameters()['id'] == this.getConfiguration()['role'])
			{
				var tool = org.ametys.uitool.ToolsManager.getInstance().getTool(target.getParameters()['id']);
				var toggleState = tool._params != null && tool._params['controlId'] == this._id;
				this.getElements().each(function(element){ element.toggle(toggleState); });
			}
		}
		else if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_TOOLCLOSED)
		{
			var targets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "tool"});
			if (target.getParameters()['id'] == this.getConfiguration()['role'])
			{
				this.getElements().each(function(element){ element.toggle(false); });
			}
		}
	}
}

/**
 * Get the parameters needed by the factory to open the tool
 * @return {Map} params The parameters needed by the factory to open the tool. Can not be null.
 */
org.ametys.cms.tool.right.control.RightsAssignmentToolButton.prototype.getOpenToolParameters = function()
{
	var params = org.ametys.cms.tool.right.control.RightsAssignmentToolButton.superclass.getOpenToolParameters.call(this);
	params['controlId'] = this._id;
	params['context'] = this.getConfiguration()['context'];
	params['selection-listener'] = this.getConfiguration()['selection-listener'];
	params['initialize'] = this.getConfiguration()['initialize-tool'];
	params['up-to-context'] = this.getConfiguration()['up-to-context'];
	params['btnLabel'] = this.getConfiguration()['label'];
	params['btnDescription'] = this.getConfiguration()['default-description'];
	params['btnIconSmall'] = this.getConfiguration()['icon-small'];
	params['btnIconLarge'] = this.getConfiguration()['icon-large']
	
	return params;
}