/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

// Ametys Namespace
Ext.namespace('org.ametys.fluent.controls');

/**
 * Creates a button in a ribbon tab
 * 
 * @class This class is the button in a ribbon
 * @extends Ext.Button
 * @constructor
 * @param {Object} config Configuration options
 */
org.ametys.fluent.controls.Button = function(config) 
{
	if (config.size == 'very-small')
	{
		config.text = null;
		config.scale = 'small';
		config.icon = config.iconSmall;
		config.iconAlign = 'left';
		config.arrowAlign = 'right';
	}
	else if (config.size == 'small')
	{
		config.scale = 'small';
		config.icon = config.iconSmall;
		config.iconAlign = 'left';
		config.arrowAlign = 'right';
	}
	else
	{
		config.scale = 'large';
		config.icon = config.iconLarge;
		config.iconAlign = 'top';
		config.arrowAlign = 'bottom';
	}

	org.ametys.fluent.controls.Button.superclass.constructor.call(this, config);
	
	this.split = (config.menu && (config.handler || config.enableToggle));
	this.on('render', this._onRenderSetTextAndClass, this);
}

Ext.extend
(
	org.ametys.fluent.controls.Button, 
	Ext.Button, 
	{
	    arrowSelector : 'em'
	}
);

/**
 * @private
 * Override toggle to work before render
 * FIXME To remove when using last SVN build (should be corrected - to test)
 */
org.ametys.fluent.controls.Button.prototype.toggle = function(state, suppressEvent)
{
	var state = state === undefined ? !this.pressed : !!state;
	if (!this.rendered)
	{
		this.pressed = state;
	}
	else
	{
		org.ametys.fluent.controls.Button.superclass.toggle.call(this, state, suppressEvent);
	}
}

/**
 * @private
 * Listener on render to reset the text (during creation a template is applied and setText is not called)
 */
org.ametys.fluent.controls.Button.prototype._onRenderSetTextAndClass = function()
{
	this.el.child("td.x-btn-tl").parent().addClass("x-btn-t");
	this.el.child("td.x-btn-bl").parent().addClass("x-btn-b");
	
	if (this.split)
	{
		this.el.addClass('x-fluent-control-splitbutton-' + this.scale);
		
        if(this.handleMouseEvents && this.split)
        {
            this.el.on("mousemove", this._onMouseMove, this);
        }	
	}
}

/**
 * Gets the text for this Button (Overriding)
 * @return {String} The button text
 */
org.ametys.fluent.controls.Button.prototype.getText = function()
{
    return this.rawText;
}

/** 
 * Override the set text method to cut the text on two lines if necessary 
 * @param {String} text The new text of the button
 */
org.ametys.fluent.controls.Button.prototype.setText = function(text)
{
	this.rawText = text;
	this.text = text;
	
    if(this.el)
    {
    	if (this.scale == 'large')
    	{
        	var textMesurer = Ext.util.TextMetrics.createInstance(this.el);

        	var minWidth = textMesurer.getWidth(this.text);
        	var minText = this.text;
        	var secondLineText = "";
        	
        	var menuOffset = this.menu ? "&#160;&#160;&#160;" : "";

        	var nextIndex = this.text.indexOf(' ', 0);
        	while (nextIndex != -1 && nextIndex < this.text.length)
        	{
        		var tmpSecondLineText = this.text.substring(nextIndex + 1) + menuOffset;
        		var testText = this.text.substring(0, nextIndex) + '<br/>' + tmpSecondLineText;
        		var testWidth = textMesurer.getWidth(testText);
        		
        		if (testWidth < minWidth)
        		{
        			minWidth = testWidth;
        			minText = testText;
        			secondLineText = tmpSecondLineText;
        		}
        		
        		nextIndex = this.text.indexOf(' ', nextIndex + 1);
        	}
        	
        	while (minWidth < 32)
        	{
        		var brpos = minText.indexOf('<br/>'); 
        		if (brpos == -1)
        		{
        			minText = "&#160;" + minText + "&#160;";
        		}
        		else
        		{
        			minText = "&#160;" + minText.substring(0, brpos) + "&#160;" + "<br/>" + "&#160;" + minText.substring(brpos + 5) + "&#160;";
        		}
        		minWidth = textMesurer.getWidth(minText);
        	}
        	
        	this.text = minText;

            if (this.menu)
            {
            	var secondLineWidth = textMesurer.getWidth(secondLineText);
            	
            	if (secondLineWidth != 0)
            	{
                	var posX = minWidth / 2 + secondLineWidth / 2 - 8 
                		+ (Ext.isChrome ? 9 : 0)
                		+ (Ext.isSafari ? 5 : 0)
                		+ (Ext.isIE ? 2 : 0)
                		+ (Ext.isOpera ? 2 : 0)
                		;

                	var em = this.el.child("td.x-btn-mc em:first");
                	em.setStyle("background-position", posX + "px bottom");
                	em.addClass("x-btn-arrow-bottom-twolines");
            	}
            }
    	}
    	else if (this.text == null)
    	{
    		this.text = '&#160;';

    		this.el.addClass("x-btn-very-small");
    	}
        
        this.el.child("td.x-btn-mc " + this.buttonSelector).update(this.text);
        this.doAutoWidth();
    }
}

/**
 * Override for split case
 * When mouse over the split button, to determine if it is over the button or the menu 
 * @private
 */
org.ametys.fluent.controls.Button.prototype._onMouseMove = function(e)
{
	if (this.isClickOnArrow(e))
	{
		this.el.removeClass('x-fluent-control-splitbutton-' + this.scale);
		this.el.addClass('x-fluent-control-splitbutton-menu-' + this.scale);
	}
	else
	{
		this.el.addClass('x-fluent-control-splitbutton-' + this.scale);
		this.el.removeClass('x-fluent-control-splitbutton-menu-' + this.scale);
	}
}

/**
 * Override for split case
 * Duplicated from splibutton
 * @private
 */
org.ametys.fluent.controls.Button.prototype.onClick = function(e, t){
    e.preventDefault();
    
    // dismiss tooltip
    // FIXME remove this block if using last extjs svn built : should be corrected (to test)
    var tooltip = Ext.QuickTips.getQuickTip();
    tooltip.clearTimer('show');
    if(tooltip.autoHide !== false)
    {
    	tooltip.delayHide();
    }
    // end of fix me
    
    if(!this.disabled)
    {
        if(this.split && this.isClickOnArrow(e) || !this.split && this.menu && !this.menu.isVisible() && !this.ignoreNextClick)
        {
            this.showMenu();

            this.fireEvent("arrowclick", this, e);
            
            if(this.arrowHandler)
            {
                this.arrowHandler.call(this.scope || this, this, e);
            }
        }
        else
        {
            if (this.enableToggle && (this.allowDepress !== false || !this.pressed))
            {
                this.toggle();
            }

            this.fireEvent("click", this, e);
            if(this.handler)
            {
                this.handler.call(this.scope || this, this, e);
            }
        }
    }
}

/**
 * Override for split case
 * Duplicated from splibutton
 * @private
 */
org.ametys.fluent.controls.Button.prototype.isClickOnArrow = function(e)
{
    return this.arrowAlign != 'bottom' ?
           e.getPageX() > this.el.child(this.buttonSelector).getRegion().right :
           e.getPageY() > this.el.getTop() + 37;
}
/**
 * Overriden for split case
 * Duplicated from splitbutton
 * @private
 * Sets this button's arrow click handler.
 * @param {Function} handler The function to call when the arrow is clicked
 * @param {Object} scope (optional) Scope for the function passed above
 */
org.ametys.fluent.controls.Button.prototype.setArrowHandler = function(handler, scope)
{
    this.arrowHandler = handler;
    this.scope = scope;
}
/**
 * Overriden for split case
 * Duplicated from splitbutton
 * @private
 */
org.ametys.fluent.controls.Button.prototype.getMenuClass = function()
{
	if (!this.split)
	{
		return org.ametys.fluent.controls.Button.superclass.getMenuClass.call(this);
	}
	else
	{
		return this.menu && this.arrowAlign != 'bottom' ? 'x-btn-split' : 'x-btn-split-bottom';
	}
}

/**
 * Change the tooltip text
 * @param {String} text The new tooltip text
 * @param {String} text The url to the new image.
 * @param {String} footer The new footer text
 */
org.ametys.fluent.controls.Button.prototype.updateTooltip = function(text, image, footer)
{
	var tooltip = org.ametys.fluent.Tooltip.create
	(
		"", 
		image, 
		text, 
		footer
	)

	this.tooltip.text = tooltip.text;

	if (this.rendered)
	{
		var btnEl = this.getEl().child(this.buttonSelector); //find the actual registered button element
		var tgt = Ext.QuickTips.getQuickTip().targets[ btnEl.id ]; //look up the qtip config object
		if (tgt != null)
		{
			tgt.text = this.tooltip.text;
		}
	}
}

/**
 * Change the button icon.
 * Set iconSmall, Medium and Large before
 */
org.ametys.fluent.controls.Button.prototype.updateIcon = function()
{
	if (this.size == 'very-small')
	{
		this.icon = this.iconSmall;
	}
	else if (this.size == 'small')
	{
		this.icon = this.iconSmall;
	}
	else
	{
		this.icon = this.iconLarge;
	}

	
	if (this.rendered)
	{
		this.getEl().child(this.buttonSelector).dom.style.backgroundImage = "url('" + this.icon + "')";
	}
}

/**
 * Display a mask while refreshing the tool
 */
org.ametys.fluent.controls.Button.prototype.refreshing = function ()
{
	if (this.rendered)
	{
		// TODO mettre une icone qui tourne
		this.getEl().child(this.buttonSelector).dom.style.backgroundImage = "url('" + context.contextPath + "/plugins/extjs/resources/images/default/grid/loading.gif')";

		//this._refreshMask = new Ext.LoadMask(this.ownerCt.getEl(), {msg: "Rafraichissement en cours"});
		//this._refreshMask.show();
	}
}

/**
 * Hide the mask while refreshing the tool
 */
org.ametys.fluent.controls.Button.prototype.stopRefreshing = function ()
{
	this.updateIcon();
	/*if (this._refreshMask)
	{
		this._refreshMask.hide();
		delete this._refreshMask;
	}*/
}
