/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.fluent.lib');

/**
 * Create the animation object
 * @class This class handles an animation on background image
 * @extends Ext.lib.ColorAnim
 * @param {Ext.Element} el Element to animate
 * @param {Map<String, String>} attributes Animation attributes
 * @param {integer} duration Duration of the animation
 * @param {String} method Animation method
 */
org.ametys.fluent.lib.BackgroundScroll = function(el, attributes, duration, method) 
{
    if (el) 
    {
        org.ametys.fluent.lib.BackgroundScroll.superclass.constructor.call(this, el, attributes, duration, method);
    }
};
		
Ext.extend(org.ametys.fluent.lib.BackgroundScroll, Ext.lib.ColorAnim);

/**
 * To string method
 * @return {String} A string representing the animation object
 */
org.ametys.fluent.lib.BackgroundScroll.prototype.toString = function() 
{
    var el = this.getEl();
    var id = el.id || el.tagName;
    return ("BackgroundScroll " + id);
};

/**
 * Do the animation
 * @param {String} attr Method attribute, should be 'bgscroll'
 * @param {integer[]} start The start position (in x et y)
 * @param {integer[]} end The end position (in x et y)
 * @return {integer[]} The current position
 */
org.ametys.fluent.lib.BackgroundScroll.prototype.doMethod = function(attr, start, end) 
{
    var val = null;

    if (attr == 'bgscroll') 
    {
        val = 
        [
            this.method(this.curFrame, start[0], end[0] - start[0], this.totalFrames),
            this.method(this.curFrame, start[1], end[1] - start[1], this.totalFrames)
        ];
    } 
    else 
    {
        val = org.ametys.fluent.lib.BackgroundScroll.superclass.doMethod.call(this, attr, start, end);
    }
    return val;
};

/**
 * Read the current position
 * @return {integer[]} The current position
 */
org.ametys.fluent.lib.BackgroundScroll.prototype.getAttr = function(attr) 
{
    var val = null;

    if (attr == 'bgscroll') 
    {
    	var bgPos = this.el.style.backgroundPosition;
		/^([^ ]*) ([^ ]*)$/.exec(bgPos);
		val = [ parseInt(RegExp.$1), parseInt(RegExp.$2) ];
		
		if (isNaN(val[0])) val[0] = 0;
		if (isNaN(val[1])) val[1] = 0;
    } 
    else 
    {
        val = org.ametys.fluent.lib.BackgroundScroll.superclass.getAttribute.call(this, attr);
    }

    return val;
};

/**
 * Write the current position
 * @param {String} attr The attribute to write (should be 'bgscroll')
 * @param {integer[]} val The new position
 * @param {String} unit Not supported
 */
org.ametys.fluent.lib.BackgroundScroll.prototype.setAttr = function(attr, val, unit) 
{
    if (attr == 'bgscroll') 
    {
    	var to = this.attributes[attr]["to"];
    	var by = this.attributes[attr]["by"];
    	if (by == null)
    	{
    		by = [1, 1];
    	}

    	var roundedVal = 
    	[
    	 	isNaN(parseInt(by[0])) ? null : Math.round((val[0] - to[0]) / by[0]) * by[0] + to[0],
    	 	isNaN(parseInt(by[1])) ? null : Math.round((val[1] - to[1]) / by[1]) * by[1] + to[1]
    	];
    	 
    	this.el.style.backgroundPosition = (roundedVal[0] != null ? roundedVal[0] + 'px ' : by[0] + ' ') + (roundedVal[1] != null ? roundedVal[1] + 'px' : by[1]);
    } 
    else 
    {
        org.ametys.fluent.lib.BackgroundScroll.superclass.setAttr.call(this, attr, val, unit);
    }
};

// Register the object on animation library
Ext.lib.Anim.bgScroll = function(el, args, duration, easing, cb, scope) 
{
	return this.run(el, args, duration, easing, cb, scope, org.ametys.fluent.lib.BackgroundScroll);
};
