/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

// Ametys Namespace
Ext.namespace('org.ametys.fluent.controls');

/**
 * Creates a button in a gallery
 * 
 * @class This class is the button in a gallery
 * @extends Ext.Button
 * @constructor
 * @param {Object} config Configuration options
 */
org.ametys.fluent.menu.GalleryButton = function(config) 
{
	config.scale = 'large';
	config.icon = config.iconLarge;
	config.iconAlign = 'top';
	config.arrowAlign = 'bottom';

	org.ametys.fluent.menu.GalleryButton.superclass.constructor.call(this, config);
	
	this.on('render', this._onRender, this);
}

Ext.extend
(
	org.ametys.fluent.menu.GalleryButton, 
	Ext.Button, 
	{
	}
);

/**
 * @private
 * Listener on render to draw the gallery
 */
org.ametys.fluent.menu.GalleryButton.prototype._onRender = function()
{
	this.el.child("td.x-btn-tl").parent().addClass("x-btn-t");
	this.el.child("td.x-btn-bl").parent().addClass("x-btn-b");
}

/**
 * Gets the text for this Button (Overriding)
 * @return {String} The button text
 */
org.ametys.fluent.menu.GalleryButton.prototype.getText = function()
{
    return this.rawText;
}

/** 
 * Override the set text method to cut the text on two lines if necessary 
 * @param {String} text The new text of the button
 */
org.ametys.fluent.menu.GalleryButton.prototype.setText = function(text)
{
	this.rawText = text;
	this.text = text;
	
    if(this.el)
    {
    	var textMesurer = Ext.util.TextMetrics.createInstance(this.el);

    	var minWidth = textMesurer.getWidth(this.text);
    	var minText = this.text;
    	var secondLineText = "";
    	
    	var menuOffset = this.menu ? "&#160;&#160;&#160;" : "";

    	var nextIndex = this.text.indexOf(' ', 0);
    	while (nextIndex != -1 && nextIndex < this.text.length)
    	{
    		var tmpSecondLineText = this.text.substring(nextIndex + 1) + menuOffset;
    		var testText = this.text.substring(0, nextIndex) + '<br/>' + tmpSecondLineText;
    		var testWidth = textMesurer.getWidth(testText);
    		
    		if (testWidth < minWidth)
    		{
    			minWidth = testWidth;
    			minText = testText;
    			secondLineText = tmpSecondLineText;
    		}
    		
    		nextIndex = this.text.indexOf(' ', nextIndex + 1);
    	}
    	
    	while (minWidth < 32)
    	{
    		var brpos = minText.indexOf('<br/>'); 
    		if (brpos == -1)
    		{
    			minText = "&#160;" + minText + "&#160;";
    		}
    		else
    		{
    			minText = "&#160;" + minText.substring(0, brpos) + "&#160;" + "<br/>" + "&#160;" + minText.substring(brpos + 5) + "&#160;";
    		}
    		minWidth = textMesurer.getWidth(minText);
    	}
    	
    	this.text = minText;
        
        this.el.child("td.x-btn-mc " + this.buttonSelector).update(this.text);
        this.doAutoWidth();
    }
}
