/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.messagebus.bus');

/**
 * This is a interface. Do not call this method.
 * @constructor
 * @class This is an interface. Inherit it to become a factory used by the {@link org.ametys.messagebus.bus.MessageBuilder}
 * @param {String} id The unique tab identifier
 * @param {Map<id, value>} configuration The configuration of the instance.
 * @param {String} The name of the plugin where the tab was declared
 */
org.ametys.messagebus.bus.MessageTargetFactory = function (id, configuration, pluginName)
{
	throw "MessageFactory is a interface. You can not do 'new org.ametys.messagebus.MessageTargetFactory()'";
}

/**
 * Inherit this method to create the {@link org.ametys.messagebus.bus.MessageTargetFactory}.
 * The purpose of this method is to create the necessary sub targets.
 * @param {String} type The type of target. Can not be null.
 * @param {Map<id, value>} parameters The parameters needed by the factory to create the message. Can not be null.
 * @return {org.ametys.messagebus.message.MessageTarget} The target created
 */
org.ametys.messagebus.bus.MessageTargetFactory.prototype.createTarget = function (type, parameters)
{
	throw "createTarget is not implemenented";
}

/**
 * Inherit this method to create the {@link org.ametys.messagebus.bus.MessageTargetFactory}.
 * The purpose of this method is to create the necessary sub targets.
 * @param {String} type The type of target. Can not be null.
 * @param {Map<id, value>} parameters The parameters needed by the factory to create the message. Can not be null.
 * @return {org.ametys.messagebus.message.MessageTarget} The targets created in a Array
 */
org.ametys.messagebus.bus.MessageTargetFactory.prototype.createTargets = function (type, parameters)
{
	throw "createTargets is not implemenented";
}
