/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.messagebus.message');

/**
 * Do not call this method. MessageTarget are created by the a {@link org.ametys.bus.message.MessageBuilder}
 * Creates a message target. MessageTarget are used at during the creation of a {@link org.ametys.messagebus.message.Message}
 * @constructor
 * @class This class represents the target of a {@link org.ametys.messagebus.message.Message} (such as 'content X' or 'page Y'). A target may imply sub-targets (such as event on 'page X' imply same event on 'content Y').
 * @param {String} type The name of the target. Such as 'content' or 'page'. Must not be null.
 * @param {Map<id, value>} params A map of parameters that allow to determine the target. Values depends on the target type. Target of type 'content' will need a identifier in the params. Must not be null.
 * @param {org.ametys.messagebus.message.MessageTarget[]} subTargets An array of implied targets. Must not be null. 
 */
org.ametys.messagebus.message.MessageTarget = function (type, parameters, subTargets)
{
	this._type = type;
	this._parameters = parameters;
	this._subTargets = subTargets;
}

/**
 * @private
 * @property {String} _type See associated parameter in constructor for details
 */
org.ametys.messagebus.message.MessageTarget.prototype._type;
/**
 * See the associated parameter in the constructor for more details.
 * @return {String} The type of the parameter. Can not be null.
 */
org.ametys.messagebus.message.MessageTarget.prototype.getType = function ()
{
	return this._type;
}

/**
 * @private
 * @property {Map<id, value>} _parameters See associated parameter in constructor for details
 */
org.ametys.messagebus.message.MessageTarget.prototype._parameters;
/**
 * See the associated parameter in the constructor for more details.
 * @return {Map<id, value>} The parameters of the target. Can not be null but empty.
 */
org.ametys.messagebus.message.MessageTarget.prototype.getParameters = function ()
{
	return this._parameters;
}

/**
 * @private
 * @property {org.ametys.messagebus.message.MessageTarget[]} _subTargets See associated parameter in constructor for details
 */
org.ametys.messagebus.message.MessageTarget.prototype._subTargets;
/**
 * See the associated parameter in the constructor for more details.
 * @return {org.ametys.messagebus.message.MessageTarget[]} The implied targets. Can not be null but empty.
 */
org.ametys.messagebus.message.MessageTarget.prototype.getSubTargets = function ()
{
	return this._subTargets;
}
