/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.ribbon');

/**
 * Do not call this method. A unique instance of org.ametys.ribbon.RibbonManager is used. Use org.ametys.ribbon.RibbonManager.getInstance() instead. 
 * @constructor
 * @class This class has a single instance. Use org.ametys.ribbon.RibbonManager.getInstance to get it.<br/>This class handle the ribbon. 
 */
org.ametys.ribbon.RibbonManager = function ()
{
	this._currentSelectionTargets = [];
	this._controls = {};
	this._tabs = {};
}

/**
 * @private
 * @property {org.ametys.ribbon.RibbonManager} _instance Unique instance.
 */
org.ametys.ribbon.RibbonManager._instance;
/**
 * This method returns the unique instance of the org.ametys.ribbon.RibbonManager
 * @static
 * @returns {org.ametys.ribbon.RibbonManager} The unique instance of the org.ametys.ribbon.RibbonManager class.
 */
org.ametys.ribbon.RibbonManager.getInstance = function()
{
	if (org.ametys.ribbon.RibbonManager._instance == null)
	{
		org.ametys.ribbon.RibbonManager._instance = new org.ametys.ribbon.RibbonManager();		
	}
	return org.ametys.ribbon.RibbonManager._instance;
}

/**
 * The name of event type when the current selection has changed.
 * This event type can have one parameter "creation" that is a string/boolean (false by default) thats indicates if the selection occurs in a creation process (false if not ; the type of selection if yes). false 'content' 'page' are correct values
 * The selection is available in the target. Can be anything (tool, content...)
 * @constant
 */
org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED = "selectionChanged";
/**
 * The name of event type when an element was created
 * This event type has no parameters.
 * The created element is available in the target. Can be anything (page, content)
 * @constant
 */
org.ametys.ribbon.RibbonManager.EVENTTYPE_CREATED = "created";
/**
 * The name of event type when an element was deleted
 * This event type has no parameters.
 * The deleted element is available in the target. Can be anything (page, content)
 * @constant
 */
org.ametys.ribbon.RibbonManager.EVENTTYPE_DELETED = "deleted";
/**
 * The name of event type when an element was moved
 * This event type has no parameters.
 * The moved element is available in the target. Can be anything (page, content)
 * @constant
 */
org.ametys.ribbon.RibbonManager.EVENTTYPE_MOVED = "moved";
/**
 * The name of event type when a metadata has changed.
 * This event type has no parameters.
 * The target which metadata has changed is available in the target.
 * @constant
 */
org.ametys.ribbon.RibbonManager.EVENTTYPE_METADATACHANGED = "metadataChanged";
/**
 * The name of event type when a minor change has been made on the metadata (refreshing the target tool is not required, for instance).
 * This event type has no parameters.
 * The target which metadata has changed is available in the target.
 * @constant
 */
org.ametys.ribbon.RibbonManager.EVENTTYPE_MINORMETADATACHANGED = "minorMetadataChanged";
/**
 * The name of event type when the workflow is changing.
 * This event type has no parameters.
 * The target which workflow is changing is available in the target.
 * @constant
 */
org.ametys.ribbon.RibbonManager.EVENTTYPE_WORKFLOWCHANGING = "workflowChanging";
/**
 * The name of event type when the workflow has changed.
 * This event type has no parameters.
 * The target which workflow has changed is available in the target.
 * @constant
 */
org.ametys.ribbon.RibbonManager.EVENTTYPE_WORKFLOWCHANGED = "workflowChanged";
/**
 * The name of event type when the lock status has changed.
 * This event type has no parameters.
 * The target which lock status has changed is available in the target.
 * @constant
 */
org.ametys.ribbon.RibbonManager.EVENTTYPE_LOCKCHANGED = "lockChanged";
/**
 * The name of event type when the focus is set on a tool.
 * This event type can have one parameter "creation" that is a string thats indicates if the selection occurs in a creation process (false if not ; the id of the tool factory if yes).
 * The tool is available in the target.
 * @constant
 */
org.ametys.ribbon.RibbonManager.EVENTTYPE_TOOLFOCUSES = "toolFocused";
/**
 * The name of event type when the current selection has changed.
 * This event type has no parameters.
 * The tool is available in the target.
 * @constant
 */
org.ametys.ribbon.RibbonManager.EVENTTYPE_TOOLBLUR = "toolBlur";
/**
 * The name of event type when a tool is activated (mean become the active tab on its tabpanel).
 * This event type has no parameters.
 * The tool is available in the target.
 * @constant
 */
org.ametys.ribbon.RibbonManager.EVENTTYPE_TOOLACTIVATED = "toolActivated";
/**
 * The name of event type when a tool is deactivated (mean not the active tab on its tabpanel - but still open).
 * This event type has no parameters.
 * The tool is available in the target.
 * @constant
 */
org.ametys.ribbon.RibbonManager.EVENTTYPE_TOOLDEACTIVATED = "toolDeactivated";
/**
 * The name of event type when the state of tool has changed
 * This event type has at least one parameter : the type of change.
 * The tool is available in the target.
 * @constant
 */
org.ametys.ribbon.RibbonManager.EVENTTYPE_TOOLSTATECHANGED = "toolStateChanged";
/**
 * The name of event type when a tool is opened (but not necessarily the active or focus tab).
 * This event type has no parameters.
 * The tool is available in the target.
 * @constant
 */
org.ametys.ribbon.RibbonManager.EVENTTYPE_TOOLOPENED = "toolOpened";
/**
 * The name of event type when a tool is closed.
 * This event type has no parameters.
 * The tool is available in the target.
 * @constant
 */
org.ametys.ribbon.RibbonManager.EVENTTYPE_TOOLCLOSED = "toolClosed";

/**
 * @private
 * @property {org.ametys.messagebus.message.MessageTarget[]} _currentSelectionTargets The current selection in the hmi. May be null.
 */
org.ametys.ribbon.RibbonManager.prototype._currentSelectionTargets;
/**
 * Get the current selection in the hmi.
 * @return {org.ametys.messagebus.message.MessageTarget[]} The current selection in the hmi. May be null.
 */
org.ametys.ribbon.RibbonManager.prototype.getCurrentSelectionTargets = function()
{
	return this._currentSelectionTargets;
}
/**
 * This method set the behavior when messages are received.
 * @param {org.ametys.messagebus.message.Message[]} messages The messages received.
 * @private
 */
org.ametys.ribbon.RibbonManager.prototype.onMessage = function (messages)
{
	for (var i = 0; i < messages.length; i++)
	{
		var message = messages[i];
		if (message.getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
		{
			this._currentSelectionTargets = message.getTargets();
		}
	}
}

/**
 * @private
 * @property {Map<id,org.ametys.ribbon.control.RibbonControl>} _controls The ribbon controls
 */
org.ametys.ribbon.RibbonManager.prototype._controls;
/**
 * Get a control
 * @return {Map<id,org.ametys.ribbon.control.RibbonControl>} _controls The ribbon controls. May not be null.
 */
org.ametys.ribbon.RibbonManager.prototype.getControls = function()
{
	return this._controls;
}
/**
 * This method sends a request to the server to know the current state of the element.
 * The parameters given will be transmeted to the server.
 * When the response has arrived, the callback function is invoked : configurationChanged
 * @param {String} type The type. Can be 'control' or 'tab'.
 * @param {org.ametys.ribbon.control.RibbonControl} control The control to refresh.
 * @param {Map<String, Object>} parameters The parameters to send to the server method of the control
 * @param integer the priority The prority (see ServerMessage) Major is the default value 
 */
org.ametys.ribbon.RibbonManager.prototype.refreshElement = function(type, element, parameters, priority)
{
	var serverMessage = new org.ametys.servercomm.ServerMessage(null, 'ribbon/' + type + '/' + element.getId(), parameters, priority || org.ametys.servercomm.ServerComm.PRIORITY_MAJOR, element._configurationChanged, element, null);
	org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);

}

/**
 * @private
 * @property {Map<id,org.ametys.ribbon.control.RibbonTab>} _tabs The ribbon tabs
 */
org.ametys.ribbon.RibbonManager.prototype._tabs;
/**
 * Get a control
 * @return {Map<id,org.ametys.ribbon.control.RibbonTab>} _tabs The ribbon tabs. May not be null.
 */
org.ametys.ribbon.RibbonManager.prototype.getTabs = function()
{
	return this._controls;
}
