/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.cms.control');

org.ametys.cms.control.CheckboxField = function(id, configuration, pluginName)
{
	org.ametys.cms.control.CheckboxField.superclass.constructor.call(this, id, configuration, pluginName);
}

Ext.extend(org.ametys.cms.control.CheckboxField, org.ametys.ribbon.control.RibbonControl, {});

org.ametys.cms.control.CheckboxField.prototype.createControl = function(size, colspan)
{
	var initFn = this.getConfiguration()['initialize'];
	if (initFn != null)
	{
		eval(initFn + "(this.getId(), this.getConfiguration(), this.getPluginName());");
	}
	
	var listeners = {};

	if (this.getConfiguration()['default-description'] != "")
	{
		var tooltip = org.ametys.fluent.Tooltip.create
		(
			this.getConfiguration()['label'],
			this.getConfiguration()['icon-large'] || this.getConfiguration()['icon-medium'] || this.getConfiguration()['icon-small'] || this.getConfiguration()['icon'],
			this.getConfiguration()['default-description'], 
			this.getConfiguration()['footer']
		);
		
		listeners['render'] = function()
						          {
								        if(Ext.isObject(tooltip))
								        {
								            Ext.QuickTips.register(Ext.apply({
								                  target: this.el.dom.id
								            }, tooltip));
								            Ext.QuickTips.register(Ext.apply({
								                  target: this.el.dom.parentNode.id
								            }, tooltip));
								        }
								        else
								        {
								            this.el.dom['qtip'] = tooltip;
								        }
						          }
	}

	for (var key in this.getConfiguration())
	{
		if (/^on(.*)$/.test(key))
		{
			listeners[RegExp.$1] = eval(this.getConfiguration()[key]);
		}
	}
	
	var element = new Ext.form.Checkbox ({
	  	  boxLabel: this.getConfiguration()['label'], 
		  width: this.getConfiguration()['width'] != null ? Number(this.getConfiguration()['width']) : 'auto',
		  name: this.getConfiguration()['name'],
		  hideLabel: true,
		  listeners: listeners
	});
	
	this.getElements().add(element);
 
	return new Ext.Panel ({
	       layout: "form",
	       colspan: colspan,
	       items:[element]
	});
}

/**
 * Get the messages to determine enable / disable
 * @param {org.ametys.messagebus.message.Message[]} messages The messages received
 */
org.ametys.cms.control.CheckboxField.prototype.onMessage = function(messages)
{
	for (var i = 0; i < messages.length; i++)
	{
		var message = messages[i];
		if (message.getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
		{
			var targets = message.getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "node";});

			var node = target != null ? target.getParameters()['object'] : null;

			if (this.getConfiguration()['selection-listener'])
			{
				eval(this.getConfiguration()['selection-listener'] + "(this, target, node);");
			}
			else
			{
				this.getElements().each(function(element) { element.setDisabled(target == null); } );
			}
		}
	}
}
