/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.cms.control');

/**
 * This widget list the possible styles for para.
 * It is based upon a special configuration given by the ParaStyleCliendSideElement
 * &lt;ul&gt;
 * 		&lt;li&gt;style-count&lt;/li&gt;
 * 		&lt;li&gt;style-I-button-label&lt;/li&gt;
 * 		&lt;li&gt;style-I-button-description&lt;/li&gt;
 * 		&lt;li&gt;style-I-button-cssclass&lt;/li&gt;
 * 		&lt;li&gt;style-I-inline-editor-render&lt;/li&gt;
 * &lt;/ul&gt;
 * This implementation do not use the configuration parameter "style-I-button-icon"
 */
org.ametys.cms.control.ComboBoxField = function(id, configuration, pluginName)
{
	org.ametys.cms.control.ComboBoxField.superclass.constructor.call(this, id, configuration, pluginName);
}

Ext.extend(org.ametys.cms.control.ComboBoxField, org.ametys.ribbon.control.RibbonControl, {});

org.ametys.cms.control.ComboBoxField.prototype.createControl = function(size, colspan)
{
	var listeners = {};

	if (this.getConfiguration()['default-description'] != "")
	{
		var tooltip = org.ametys.fluent.Tooltip.create
		(
			this.getConfiguration()['label'],
			this.getConfiguration()['icon-large'] || this.getConfiguration()['icon-medium'] || this.getConfiguration()['icon-small'] || this.getConfiguration()['icon'],
			this.getConfiguration()['default-description'], 
			this.getConfiguration()['footer']
		);
	
		listeners['render'] = function()
					          {
	
			
							        if(Ext.isObject(tooltip))
							        {
							            Ext.QuickTips.register(Ext.apply({
							                  target: this.el.id
							            }, tooltip));
							            if (this.label)
							            {
								            Ext.QuickTips.register(Ext.apply({
								                  target: this.label
								            }, tooltip));
							            }
							        }
							        else
							        {
							            this.el.dom['qtip'] = tooltip;
							            if (this.label)
							            {
							            	this.label.dom['qtip'] = tooltip;
							            }
							        }
					          }
	}

	for (var key in this.getConfiguration())
	{
		if (/^on(.*)$/.test(key))
		{
			listeners[RegExp.$1] = eval(this.getConfiguration()[key]);
		}
	}
	
	var conf = {
    	store: this.createStore(),
    	mode: 'local',

    	hideLabel: this.getConfiguration()['label'] == null,
    	fieldLabel: this.getConfiguration()['label'],

		forceSelection : true,
		triggerAction: 'all',
		
		editable: false,
		valueField: 'id',
		displayField: 'text',
			
		listeners: listeners
	};
	
	if (this.getConfiguration()["template"] != null)
	{
		conf.tpl = new Ext.XTemplate(this.getConfiguration()["template"].replace(/'/g, '"'));
	}

	var labelWidth = this.getConfiguration()['label-width'] != null ? Number(this.getConfiguration()['label-width']) : 60;
	var width = this.getConfiguration()['width'] != null ? Number(this.getConfiguration()['width']) : 200;
	
	if (this.getConfiguration()["width"] != null)
	{
		conf.width = width;
		conf.listWidth = width;
	}
	
	var element = new Ext.form.ComboBox(conf);
	
	element.addListener ('select', function (combo, record, index) { eval(this.getConfiguration()['action'] + ".defer(10, this, [combo, record, index]);") }, this);
	
	this.getElements().add(element);
	
	var panel = new Ext.Panel ({
	       layout: "form",
	       labelAlign: size == 'large' && conf.fieldLabel ? 'top' : 'left',
	       labelWidth : labelWidth,
	       colspan: colspan,

		   width: (this.getConfiguration()['label'] != null ? labelWidth + 5 : 0) + width,

	       items:[element]
	});
	return panel;
}

org.ametys.cms.control.ComboBoxField.prototype.createStore = function()
{
	var data = new Array();
	for (var i = 0; i < parseInt(this.getConfiguration()['count']); i++)
	{
		var label = this.getConfiguration()[i + '-label'];
		var value = this.getConfiguration()[i + '-value'];
		
		data.push([value, label]);
	}
	
	var store = new Ext.data.SimpleStore({
        id: 0,
        fields: [
            'id',
            'text'
        ],
        data: data
    });
	
	return store;
}


/**
 * Get the messages to determine enable / disable and the combo value
 * @param {org.ametys.messagebus.message.Message[]} messages The messages received
 */
org.ametys.cms.control.ComboBoxField.prototype.onMessage = function(messages)
{
	for (var i = 0; i < messages.length; i++)
	{
		var message = messages[i];
		if (message.getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
		{
			var targets = message.getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) { return target.getType() == "node";});

			var node = target != null ? target.getParameters()['object'] : null;

			if (this.getConfiguration()['selection-listener'])
			{
				eval(this.getConfiguration()['selection-listener'] + "(this, target, node);");
			}
			else
			{
				this.getElements().each(function(element) {element.setDisabled(target == null);});
			}
		}
	}
}
