/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.ribbon.control');

/**
 * Creates the control. There is one instance per control. Extends this method to initialize your component.
 * @param {String} id The unique button identifier
 * @param {Map<id, value>} configuration The configuration of the control instance.
 * @param {String} The name of the plugin where the control was declared
 * @class This interface is used for ribbon control. You must implement it to creates a control.
 * @constructor
 */
org.ametys.ribbon.control.RibbonControl = function(id, configuration, pluginName)
{
	this._elements = new Ext.util.MixedCollection();
	
	org.ametys.ribbon.control.RibbonControl.superclass.constructor.call(this, id, configuration, pluginName);
	
	org.ametys.messagebus.MessageBus.getInstance().register(this);
}

Ext.extend(org.ametys.ribbon.control.RibbonControl, org.ametys.ribbon.control.RibbonElement, {});

/**
 * This method is call once. Implement this method to create the control in the ribbon.
 * @param {String} size The size between 'large', 'small' and 'very-small'
 * @param {integer} colspan The configured colspan. Must be transmited to the control.
 * @return {Ext.form.field} The control created. Ready to be added to the ribbon. See the ribbon documentation for the list of class supported.
 */
org.ametys.ribbon.control.RibbonControl.prototype.createControl = function(size, colspan)
{
	throw "RibbonControl.createControl method has to be implemented";
}

/**
 * @private 
 * @property {element} _elements The elements created by the createControl call
 * 
 */
org.ametys.ribbon.control.RibbonControl.prototype._elements;
/**
 * Get the elements created by the create control call
 * @return {Ext.util.MixedCollection} The elements created by the createControl call
 */
org.ametys.ribbon.control.RibbonControl.prototype.getElements = function ()
{
	return this._elements;
}