/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.ribbon.control.button');

/**
 * Create the control instance.
 * @param {String} id The unique identifier
 * @param {Map<id, value>} configuration The configuration of the control instance.
 * @param {String} pluginName The name of the declaring plugin
 * @class This class implements the behavior for an action.
 * @extends org.ametys.ribbon.control.RibbonControl
 */
org.ametys.ribbon.control.button.ActionButton = function(id, configuration, pluginName)
{
	org.ametys.ribbon.control.button.ActionButton.superclass.constructor.call(this, id, configuration, pluginName);
}

Ext.extend(org.ametys.ribbon.control.button.ActionButton, org.ametys.ribbon.control.RibbonControl, {});

/**
 * Creates the toggle button
 * @param {String} size The size between 'large', 'small' and 'very-small'
 * @param {integer} colspan The configured colspan. Must be transmited to the control.
 * @return {Ext.form.field} The toggle button created. 
 */
org.ametys.ribbon.control.button.ActionButton.prototype.createControl = function(size, colspan)
{
	var initFn = this.getConfiguration()['initialize'];
	if (initFn != null)
	{
		eval(initFn + "(this.getId(), this.getConfiguration(), this.getPluginName());");
	}
	
	this._toolTipImage = this._getTooltipImage ();
	this._toolTipText = this.getConfiguration()['default-description'];
	this._toolTipFooter = this.getConfiguration()['footer'];
	
	var element = new org.ametys.fluent.controls.Button({
		text: this.getConfiguration()['label'], 
		iconSmall: context.contextPath + this.getConfiguration()['icon-small'],
		iconLarge: context.contextPath + this.getConfiguration()['icon-medium'],
		size: size,
		colspan: colspan,
		
		disabled: this.getConfiguration()['disabled'] == "true",
		
		tooltip: org.ametys.fluent.Tooltip.create(
			this.getConfiguration()['label'], 
			this._toolTipImage, 
			this._toolTipText, 
			this._toolTipFooter 
		),
		
		handler: this._onPress,
		
		controlId: this.getId()
	});
	
	this.getElements().add (element);
	
	return element;
}

/**
 * Update the tooltip text of this action button
 * @param text The new text
 * @param image The new image. Can be null to use the current one.
 * @param footer The new image. Can be null to use the current one.
 */
org.ametys.ribbon.control.button.ActionButton.prototype.updateTooltip = function (text, image, footer)
{
	this._toolTipImage = image != null ? image : this._toolTipImage;;
	this._toolTipText = text != null ? text : this._toolTipText;
	this._toolTipFooter = footer != null ? footer : this._toolTipFooter;
	
	var t = this;
	
	this.getElements().each(function(element) { element.updateTooltip (t._toolTipText, t._toolTipImage, t._toolTipFooter); } )
}

/**
 * @private
 * Get the image to use for tooltip
 */
org.ametys.ribbon.control.button.ActionButton.prototype._getTooltipImage = function ()
{
	if (this.getConfiguration()['icon-large'] != null)
	{
		return context.contextPath + this.getConfiguration()['icon-large']
	}
	else if (this.getConfiguration()['icon-medium'] != null)
	{
		return context.contextPath + this.getConfiguration()['icon-medium']
	}
	else if (this.getConfiguration()['icon-small'] != null)
	{
		return context.contextPath + this.getConfiguration()['icon-small']
	}
	return null;
}

/**
 * @private
 * This handler is called when the toogle button state change
 */
org.ametys.ribbon.control.button.ActionButton.prototype._onPress = function(button, event)
{
	var control = org.ametys.ribbon.RibbonManager.getInstance().getControls()[this.controlId];
	if (control.getConfiguration()['action'] != null)
	{
		eval(control.getConfiguration()['action'] + "(control.getId(), control.getConfiguration(), control.getPluginName());");
	}
}

/**
 * This method is called when the configuration has changed. This method is the callback of the RibbonManager.refreshState method.
 * Does nothing.
 * @param {Map<id, value>} configuration The configuration sent by the server
 */
org.ametys.ribbon.control.button.ActionButton.prototype.configurationChanged = function(configuration)
{
	// nothing
}
