/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.ribbon.control.button');

/**
 * ActionButton that moreover is disabled when a the user rights are not sufficient. The concerned target must be a target with the parameter 'right' containing the user rights on target context.
 * @extends org.ametys.ribbon.control.button.ActionSelectionButton
 * The configuration of the control instance. The key 'target-type' represents the name of the target that will make the button enable when this kind of target is in the {@see org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED} message. You can optionnaly set a subtarget-type that do the same on the immediate first child
 */
org.ametys.ribbon.control.button.RightActionSelectionButton = function(id, configuration, pluginName)
{
	org.ametys.ribbon.control.button.RightActionSelectionButton.superclass.constructor.call(this, id, configuration, pluginName);
}

Ext.extend(org.ametys.ribbon.control.button.RightActionSelectionButton, org.ametys.ribbon.control.button.ActionSelectionButton, {});

org.ametys.ribbon.control.button.RightActionSelectionButton.prototype.onMessage = function(messages)
{
	for (var i=0; i < messages.length; i++)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
		{
			var targets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, this._testTarget.createDelegate(this));
			
			if (target != null)
			{
				if (!this._hasRight(target))
				{
					var text = this._getTooltip(this.getConfiguration()["no-right-description"]);
					this.updateTooltip(text, null, null);
					
					this.getElements().each(function(element) {element.disable();});
				}
				else
				{
					this.getElements().each(function(element) {element.enable();});
					
					this.updateTooltip(this.getConfiguration()["default-description"], null, null);
				}
			}
			else
			{
				var text = this._getTooltip(this.getConfiguration()["no-selection-description"]);
				this.updateTooltip(text, null, null);
				this.getElements().each(function(element) {element.disable();});
			}
		}
	}
}

/**
 * Checks the user right
 * @return true if the user has right to do the action
 * @private
 */
org.ametys.ribbon.control.button.RightActionSelectionButton.prototype._hasRight = function(target)
{
	if (!this.getConfiguration()['right-id'])
	{
		// No right is needed
		return true;
	}
	
	var neededRights = this.getConfiguration()['right-id'].split('|');
	
	var rights = target.getParameters().rights;
	for (var i=0;  rights != null && i < rights.length; i++)
	{
		if (neededRights.indexOf(rights[i]) != -1)
		{
			return true;
		}
	}
	return false;
}

org.ametys.ribbon.control.button.RightActionSelectionButton.prototype._getTooltip = function (addedText)
{
	var tooltip = this.getConfiguration()["default-description"];
	if (addedText != null && addedText.length > 0)
	{
		tooltip += "<br/><br/>";
		
		tooltip += addedText;
	}
	return tooltip;
}