/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.ribbon.control.button');

/**
 * Create the control instance.
 * @param {String} id The unique identifier
 * @param {Map<id, value>} configuration The configuration of the control instance.
 * @param {String} pluginName The name of the declaring plugin
 * @class This class implements the behavior for unique instance tool. These are toggle buttons showing hiding the tool.
 * @extends org.ametys.ribbon.control.button.ActionButton
 */
org.ametys.ribbon.control.button.ToolButton = function(id, configuration, pluginName)
{
	org.ametys.ribbon.control.button.ToolButton.superclass.constructor.call(this, id, configuration, pluginName);
}

Ext.extend(org.ametys.ribbon.control.button.ToolButton, org.ametys.ribbon.control.button.ActionButton, {});

/**
 * @private
 * This handler is called when the button was pressed
 */
org.ametys.ribbon.control.button.ToolButton.prototype._onPress = function(button, state)
{
	var control = org.ametys.ribbon.RibbonManager.getInstance().getControls()[this.controlId];
	org.ametys.uitool.ToolsManager.getInstance().openTool(control.getConfiguration()['role'], control.getOpenToolParameters());
}

/**
 * Get the parameters needed by the factory to open the tool
 * @return {Map} params The parameters needed by the factory to open the tool. Can not be null.
 */
org.ametys.ribbon.control.button.ToolButton.prototype.getOpenToolParameters = function()
{
	var context = this.getConfiguration()['context'];
	return {context: context};
}
