/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.ribbon.control.button');

/**
 * UniqueInstanceToolButton that moreover is disabled when a page is not selected
 * The configuration of the control instance. The key 'target-type' represents the name of the target that will make the button enable when this kind of target is in the {@see org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED} message. You can optionnaly set a subtarget-type that do the same on the immediate first child
 */
org.ametys.ribbon.control.button.UniqueInstanceToolAndRightSelectionButton = function(id, configuration, pluginName)
{
	org.ametys.ribbon.control.button.UniqueInstanceToolAndRightSelectionButton.superclass.constructor.call(this, id, configuration, pluginName);
}

Ext.extend(org.ametys.ribbon.control.button.UniqueInstanceToolAndRightSelectionButton, org.ametys.ribbon.control.button.UniqueInstanceToolAndSelectionButton, {});

org.ametys.ribbon.control.button.UniqueInstanceToolAndRightSelectionButton.prototype.onMessage = function(messages)
{
	org.ametys.ribbon.control.button.UniqueInstanceToolAndRightSelectionButton.superclass.onMessage.call(this, messages);

	if (this.getElements().item(0).disabled)
	{
		return;
	}
	
	for (var i=0; i < messages.length; i++)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
		{
			var targets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, this._testTarget.createDelegate(this));
			
			if (target != null)
			{
				if (!this._hasRight(target))
				{
					var text = this.getConfiguration()["no-right-description"] != null ? this.getConfiguration()["no-right-description"] : this.getConfiguration()["default-description"];
					this.updateTooltip(text, null, null);
					this.getElements().each(function (element) { element.disable(); });
				}
				else
				{
					this.getElements().each(function (element) { element.enable(); });
					this.updateTooltip(this.getConfiguration()["default-description"], null, null);
				}
			}
			else
			{
				var text = this.getConfiguration()["no-selection-description"] != null ? this.getConfiguration()["no-selection-description"] : this.getConfiguration()["default-description"];
				this.updateTooltip(text, null, null);
				this.getElements().each(function (element) { element.disable(); });
			}
		}
	}
}

/**
 *  @private
 * Checks the user right on target
 * @param target the target to test
 * @return true if the user has right to use the tool
 */
org.ametys.ribbon.control.button.UniqueInstanceToolAndRightSelectionButton.prototype._hasRight = function(target)
{
	if (!this.getConfiguration()['right-id'])
	{
		// No right is needed
		return true;
	}
	
	var neededRights = this.getConfiguration()['right-id'].split('|');
	
	var rights = target.getParameters().rights;
	for (var i=0;  rights != null && i < rights.length; i++)
	{
		if (neededRights.indexOf(rights[i]) != -1)
		{
			return true;
		}
	}
	return false;
}
