/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.uitool.tool');

/**
 * Creates an instance of org.ametys.uitool.tool.ToolFactory
 * @class This interface represents a factory.<br/>You should extend this class to create your own factory.
 * @param {String} id The unique id of the factory
 * @param {Map} config Configuration options 
 * @param {String} pluginName The name of the plugin where the factory was declared
 * @constructor
 */
org.ametys.uitool.tool.ToolFactory = function(id, config, pluginName) 
{
	this._id = id;
	this._config = config;
	this._pluginName = pluginName;
}

/**
 * @private
 * @property {String} _id The unique id of the factory
 */
org.ametys.uitool.tool.ToolFactory.prototype._id;

/**
 * @private
 * @property {String} _pluginName The name of the plugin where the factory was declared
 */
org.ametys.uitool.tool.ToolFactory.prototype._pluginName;
/**
 * Get the plugin name of the factory.
 * @returns {String} The plugin name of the factory.
 */
org.ametys.uitool.tool.ToolFactory.prototype.getPluginName = function ()
{
	return this._pluginName;
}

/**
 * @private
 * @property {Map} _config The configuration options
 */
org.ametys.uitool.tool.ToolFactory.prototype._config;

/**
 * Inherit this method in your own factory.<br/>The purpose of this method is to open the tool to make it visible in the interface.
 * @param {Map} params The parameters needed by the factory to open the tool. Can not be null.
 * @return {Ext.org.ametys.uitool.tool.Tool} The tool to open.
 */
org.ametys.uitool.tool.ToolFactory.prototype.openTool = function(params) 
{
	throw "org.ametys.uitool.tool.ToolFactory#openTool is not implemented";
}

/**
 * Inherit this method in your own factory.<br/>The purpose of this method is to close the tool.
 * @param {org.ametys.uitool.tool.Tool} tool The tool to close.
 */
org.ametys.uitool.tool.ToolFactory.prototype.closeTool = function(tool) 
{
	throw "org.ametys.uitool.tool.ToolFactory#closeTool is not implemented";
}