/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.utils');

/**
 * Utilities for tooltip
 */
org.ametys.utils.Tooltip = {};

/**
 * Utility to create a tooltip. If a tooltip of same id exists, it will be destroy.
 * @param id The tooltip id. The id will be prefixed by 'tooltip-'
 * @param targetEl The target element
 * @param title The tooltip title. Can not be null.
 * @param text The tooltip text. Can not be null.
 * @param image The icon path for the tooltip in 32x32 pixels. Can be null.
 * @param footer The footer text. Can be null.
 * @param dismissDelay Delay in milliseconds before the tooltip automatically hides. Can be null or equals to 0 to disable automatic hiding
 * @param width The tooltip width. Can be null. Defaults to 220 pixels with icon and 180 pixels with no icon.
 */
org.ametys.utils.Tooltip.createTooltip = function (id, targetEl, title, text, image, footer, dismissDelay, width)
{
	var tooltip = Ext.getCmp('tooltip-' + id);
	if (tooltip)
	{
		tooltip.destroy();
	}
	
	var content = org.ametys.utils.Tooltip.createTooltipContent (title, text, image, footer);
	
	return new Ext.ToolTip({
		id: 'tooltip-' + id,
		
	    target: targetEl,
	    html: content,
	    
	    width: width != null ? width : (image ? 220 : 180),
	    dismissDelay: dismissDelay != null ? dismissDelay : 0
	});
}

/**
 * Utility to create a HTML content for tooltip
 * @param title The tooltip title. Can not be null.
 * @param text The tooltip text. Can not be null.
 * @param image The icon path for the tooltip. Can be null
 * @param footer The footer text. Can be null
 */
org.ametys.utils.Tooltip.createTooltipContent = function (title, text, image, footer)
{
	var html = "<div class='ametys-cms-tooltip'>";
	
	html += "<div class='ametys-cms-tooltip-title'>";
	html += "<b>" + title + "</b>";
	html += "</div>";
	
	html += "<div class='ametys-cms-tooltip-text'>";
	if (image)
	{
		html += "<img class='ametys-cms-tooltip-img' src='" + image + "'/>"
	}
	html += text
	html += "</div>";
	html += "<div class='x-clear'></div>";
	
	if (footer)
	{
		html += "<div class='ametys-cms-tooltip-footer'>" + footer + "</div>"
	}
	html += "</div>";
	
	return html;
}

/**
 * Destroy a tooltip
 */
org.ametys.utils.Tooltip.deleteTooltip = function (id)
{
	var tooltip = Ext.getCmp('tooltip-' + id);
	if (tooltip)
	{
		tooltip.destroy();
	}
}