/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.utils');

org.ametys.utils.Utils = {};

/**
 * Trunk the given text with '...' if the text width is greater than the given max width. 
 * @param {String|HTMLElement} el The element, DOM node or id that the instance will be bound to
 * @param {String} text The text to trunk
 * @param {Number} maxWidth The max width in pixels.
 * @return The truncated text or the full text if the text is not oversized.
 * @static
 */
org.ametys.utils.Utils.getTruncatedText = function (el, text, maxWidth)
{
	var textMesurer = Ext.util.TextMetrics.createInstance(el);
	
	if (textMesurer.getWidth (text) > maxWidth)
	{
		var truncatedText = text;
		while (textMesurer.getWidth (truncatedText + '...') > maxWidth)
		{
			truncatedText = truncatedText.substring (0, truncatedText.length -1);
		}
		
		return truncatedText + '...';
	}
	else
	{
		return text;
	}
}